@@ -3,7 +3,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "previewsingleapplication.h"
+
+#include <dfm-base/utils/windowutils.h>
+
 #include <QProcessEnvironment>
+
 #ifdef DFM_ORGANIZATION_NAME
 #    define ORGANIZATION_NAME DFM_ORGANIZATION_NAME
 #else
@@ -12,6 +16,11 @@
 
 int main(int argc, char *argv[])
 {
+    // 管理员模式可能丢失 QT_QPA_PLATFORM
+    if (DFMBASE_NAMESPACE::WindowUtils::isX11() && qEnvironmentVariableIsEmpty("QT_QPA_PLATFORM")) {
+        qputenv("QT_QPA_PLATFORM", "dxcb");
+    }
+
     // singlentan process
     PreviewSingleApplication app(argc, argv);
 
@@ -32,9 +41,13 @@ int main(int argc, char *argv[])
     bool isSinglentanApp = app.setSingleInstance(uniqueKey);
 
     if (isSinglentanApp) {
+        fmInfo() << "main: File preview application started as primary instance, version:" << app.applicationVersion();
         PreviewSingleApplication::processArgs(app.arguments());
-        return app.exec();
+        int ret = app.exec();
+        fmInfo() << "main: File preview application exiting with code:" << ret;
+        return ret;
     } else {
+        fmDebug() << "main: Detected existing preview instance, forwarding to primary instance";
         app.handleNewClient(uniqueKey);
         return 0;
     }
