@@ -71,32 +71,36 @@ LocalFileHandler::~LocalFileHandler()
 QUrl LocalFileHandler::touchFile(const QUrl &url, const QUrl &tempUrl /*= QUrl()*/)
 {
     if (!url.isValid()) {
-        qCWarning(logDFMBase) << "Invalid URL provided to touchFile:" << url;
+        qCWarning(logDFMBase) << "LocalFileHandler::touchFile: Invalid URL provided:" << url;
         return QUrl();
     }
 
+    qCDebug(logDFMBase) << "LocalFileHandler::touchFile: Creating file at:" << url;
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(url) };
     if (!oper) {
-        qCWarning(logDFMBase) << "Create operator failed, url: " << url;
+        qCCritical(logDFMBase) << "LocalFileHandler::touchFile: Failed to create DOperator for:" << url;
         return QUrl();
     }
 
     bool success = oper->touchFile();
     if (!success) {
-        qCWarning(logDFMBase) << "Touch file failed, url: " << url;
+        qCWarning(logDFMBase) << "LocalFileHandler::touchFile: Failed to create file:" << url
+                              << "Error:" << oper->lastError().errorMsg();
         d->setError(oper->lastError());
         return QUrl();
     } else {   // fix bug 189699 When the iPhone creates a file, the gio is created successfully, but there is no file
         auto info = InfoFactory::create<FileInfo>(url, Global::CreateFileInfoType::kCreateFileInfoSync);
         if (!info || !info->exists()) {
+            qCWarning(logDFMBase) << "LocalFileHandler::touchFile: File creation reported success but file does not exist:" << url;
             d->lastError.setCode(DFMIOErrorCode::DFM_IO_ERROR_NOT_SUPPORTED);
             return QUrl();
         }
     }
 
     auto templateUrl = d->loadTemplateInfo(url, tempUrl);
-    qCInfo(logDFMBase, "touchFile source file: %s, Template file %s, succeeded by dfmio function touchFile!",
-           url.path().toStdString().c_str(), tempUrl.path().toStdString().c_str());
+    qCInfo(logDFMBase) << "LocalFileHandler::touchFile: Successfully created file:" << url
+                       << "Template:" << (tempUrl.isValid() ? tempUrl.toString() : "none");
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, url);
 
     return templateUrl;
@@ -108,25 +112,26 @@ QUrl LocalFileHandler::touchFile(const QUrl &url, const QUrl &tempUrl /*= QUrl()
  */
 bool LocalFileHandler::mkdir(const QUrl &dir)
 {
+    qCDebug(logDFMBase) << "LocalFileHandler::mkdir: Creating directory:" << dir;
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(dir) };
     if (!oper) {
-        qCWarning(logDFMBase) << "create operator failed, url: " << dir;
+        qCCritical(logDFMBase) << "LocalFileHandler::mkdir: Failed to create DOperator for:" << dir;
         return false;
     }
 
     bool success = oper->makeDirectory();
     if (!success) {
-        qCWarning(logDFMBase) << "make directory failed, url: " << dir;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::mkdir: Failed to create directory:" << dir
+                              << "Error:" << oper->lastError().errorMsg();
         d->setError(oper->lastError());
-
         return false;
     }
 
     FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(dir);
     fileInfo->refresh();
 
-    qCInfo(logDFMBase, "mkdir source file : %s, successed by dfmio function makeDirectory!", dir.path().toStdString().c_str());
+    qCInfo(logDFMBase) << "LocalFileHandler::mkdir: Successfully created directory:" << dir;
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, dir);
 
     return true;
@@ -138,23 +143,25 @@ bool LocalFileHandler::mkdir(const QUrl &dir)
  */
 bool LocalFileHandler::rmdir(const QUrl &url)
 {
+    qCDebug(logDFMBase) << "LocalFileHandler::rmdir: Moving directory to trash:" << url;
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(url) };
 
     if (!oper) {
-        qCWarning(logDFMBase) << "create operator failed, url: " << url;
+        qCCritical(logDFMBase) << "LocalFileHandler::rmdir: Failed to create DOperator for:" << url;
         return false;
     }
 
     QString targetTrash = oper->trashFile();
     if (targetTrash.isEmpty()) {
-        qCWarning(logDFMBase) << "trash file failed, url: " << url;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::rmdir: Failed to move directory to trash:" << url
+                              << "Error:" << oper->lastError().errorMsg();
         d->setError(oper->lastError());
-
         return false;
     }
 
-    qCWarning(logDFMBase, "rmdir source file : %s, successed by dfmio function trashFile!", url.path().toStdString().c_str());
+    qCInfo(logDFMBase) << "LocalFileHandler::rmdir: Successfully moved directory to trash:" << url
+                       << "Trash location:" << targetTrash;
 
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileDeleted, url);
 
@@ -188,21 +195,23 @@ bool LocalFileHandler::renameFile(const QUrl &url, const QUrl &newUrl, const boo
         const QUrl &toParentUrl = UrlRoute::urlParent(newUrl);
         if (fromParentUrl == toParentUrl) {
             // if fileinfo or other operation query info in mtp device, file will rename false. mtp device is busy
+            qCDebug(logDFMBase) << "LocalFileHandler::renameFile: Renaming MTP file:" << url << "to:" << newUrl;
             const QString &newName = newUrl.fileName();
             QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(url) };
             if (!oper) {
-                qCWarning(logDFMBase) << "create operator failed, url: " << url;
+                qCCritical(logDFMBase) << "LocalFileHandler::renameFile: Failed to create DOperator for MTP file:" << url;
                 return false;
             }
 
             bool success = oper->renameFile(newName);
-            qCInfo(logDFMBase, "rename source file : %s , target file :%s , successed : %d  in mtp\
-                  by dfmio function rename!",
-                   url.path().toStdString().c_str(),
-                   newUrl.path().toStdString().c_str(),
-                   success);
-            if (success)
+            if (success) {
+                qCInfo(logDFMBase) << "LocalFileHandler::renameFile: Successfully renamed MTP file:" << url
+                                   << "to:" << newUrl;
                 return true;
+            } else {
+                qCWarning(logDFMBase) << "LocalFileHandler::renameFile: Failed to rename MTP file:" << url
+                                      << "to:" << newUrl << "Error:" << oper->lastError().errorMsg();
+            }
         }
     }
 
@@ -211,40 +220,39 @@ bool LocalFileHandler::renameFile(const QUrl &url, const QUrl &newUrl, const boo
     const QString &targetFile = newUrl.toLocalFile();
 
     if (DFMIO::DFile(targetFile).exists()) {
+        qCWarning(logDFMBase) << "LocalFileHandler::renameFile: Target file already exists:" << targetFile;
         DFMIOError error;
         error.setCode(DFM_IO_ERROR_EXISTS);
         d->setError(error);
         return false;   // TODO(xust/lanxuesong): user interaction?
     }
 
+    qCDebug(logDFMBase) << "LocalFileHandler::renameFile: Using system rename API for:" << sourceFile << "to:" << targetFile;
+
     if (::rename(sourceFile.toLocal8Bit().constData(), targetFile.toLocal8Bit().constData()) == 0) {
         FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileDeleted, url);
         FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, newUrl);
 
         FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(newUrl);
         fileInfo->refresh();
-        qCInfo(logDFMBase, "rename source file : %s , target file :%s successed by system function rename!",
-               sourceFile.toStdString().c_str(),
-               targetFile.toStdString().c_str());
+        qCInfo(logDFMBase) << "LocalFileHandler::renameFile: Successfully renamed file using system API:"
+                           << sourceFile << "to:" << targetFile;
         return true;
     }
 
+    qCDebug(logDFMBase) << "LocalFileHandler::renameFile: System rename failed, trying dfmio rename for:" << url;
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(url) };
     if (!oper) {
-        qCWarning(logDFMBase) << "create operator failed, url: " << url;
+        qCCritical(logDFMBase) << "LocalFileHandler::renameFile: Failed to create DOperator for:" << url;
         return false;
     }
 
     bool success = oper->renameFile(newUrl);
-    qCInfo(logDFMBase, "rename source file : %s , target file :%s , successed : %d \
-          by dfmio function rename!",
-           url.path().toStdString().c_str(),
-           newUrl.path().toStdString().c_str(), success);
     if (!success) {
-        qCWarning(logDFMBase) << "rename file failed, url: " << url;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::renameFile: Failed to rename file:" << url
+                              << "to:" << newUrl << "Error:" << oper->lastError().errorMsg();
         d->setError(oper->lastError());
-
         return false;
     }
 
@@ -254,6 +262,9 @@ bool LocalFileHandler::renameFile(const QUrl &url, const QUrl &newUrl, const boo
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileDeleted, url);
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, newUrl);
 
+    qCInfo(logDFMBase) << "LocalFileHandler::renameFile: Successfully renamed file using dfmio:"
+                       << url << "to:" << newUrl;
+
     return true;
 }
 /*!
@@ -272,8 +283,12 @@ bool LocalFileHandler::openFile(const QUrl &fileUrl)
  */
 bool LocalFileHandler::openFiles(const QList<QUrl> &fileUrls)
 {
-    if (fileUrls.isEmpty())
+    if (fileUrls.isEmpty()) {
+        qCDebug(logDFMBase) << "LocalFileHandler::openFiles: No files to open, returning success";
         return true;
+    }
+
+    qCDebug(logDFMBase) << "LocalFileHandler::openFiles: Opening" << fileUrls.size() << "files";
 
     QList<QUrl> pathList;
     bool result = false;
@@ -283,18 +298,24 @@ bool LocalFileHandler::openFiles(const QList<QUrl> &fileUrls)
     for (const QUrl &fileUrl : fileUrls) {
         // Skip invalid URLs
         if (!fileUrl.isValid() || !fileUrl.isLocalFile()) {
-            qCWarning(logDFMBase) << "Invalid URL provided:" << fileUrl;
+            qCWarning(logDFMBase) << "LocalFileHandler::openFiles: Skipping invalid URL:" << fileUrl;
             continue;
         }
 
+        qCDebug(logDFMBase) << "LocalFileHandler::openFiles: Processing file:" << fileUrl;
+
         // 1. Handle symlinks
         auto resolvedUrl = d->resolveSymlink(fileUrl);
-        if (!resolvedUrl)   // If resolution fails, continue to next file
+        if (!resolvedUrl) {   // If resolution fails, continue to next file
+            qCDebug(logDFMBase) << "LocalFileHandler::openFiles: Failed to resolve symlink for:" << fileUrl;
             continue;
+        }
 
         // 2. Handle executable files
-        if (d->handleExecutableFile(*resolvedUrl, &result))
+        if (d->handleExecutableFile(*resolvedUrl, &result)) {
+            qCDebug(logDFMBase) << "LocalFileHandler::openFiles: Handled as executable file:" << *resolvedUrl;
             continue;
+        }
 
         // 3. Collect file paths to open
         d->collectFilePath(*resolvedUrl, &pathList);
@@ -302,9 +323,18 @@ bool LocalFileHandler::openFiles(const QList<QUrl> &fileUrls)
 
     // 4. Open collected files
     if (!pathList.empty()) {
+        qCDebug(logDFMBase) << "LocalFileHandler::openFiles: Opening" << pathList.size() << "collected files";
         result = d->doOpenFiles(pathList);
+        if (result) {
+            qCInfo(logDFMBase) << "LocalFileHandler::openFiles: Successfully opened" << pathList.size() << "files";
+        } else {
+            qCWarning(logDFMBase) << "LocalFileHandler::openFiles: Failed to open some or all files";
+        }
     } else {
         result = d->invalidPath.isEmpty();
+        if (!result) {
+            qCWarning(logDFMBase) << "LocalFileHandler::openFiles: No valid files to open, invalid paths:" << d->invalidPath.size();
+        }
     }
 
     return result;
@@ -330,20 +360,22 @@ bool LocalFileHandler::openFilesByApp(const QList<QUrl> &fileUrls, const QString
     bool ok = false;
 
     if (desktopFile.isEmpty()) {
-        qCWarning(logDFMBase) << "Failed to open desktop file with gio: app file path is empty";
+        qCWarning(logDFMBase) << "LocalFileHandler::openFilesByApp: Desktop file path is empty";
         return ok;
     }
 
     if (fileUrls.isEmpty()) {
-        qCWarning(logDFMBase) << "Failed to open desktop file with gio: file path is empty";
+        qCWarning(logDFMBase) << "LocalFileHandler::openFilesByApp: No files provided to open";
         return ok;
     }
 
-    qCDebug(logDFMBase) << desktopFile << fileUrls;
+    qCDebug(logDFMBase) << "LocalFileHandler::openFilesByApp: Opening" << fileUrls.size()
+                        << "files with app:" << desktopFile;
 
     GDesktopAppInfo *appInfo = g_desktop_app_info_new_from_filename(desktopFile.toLocal8Bit().constData());
     if (!appInfo) {
-        qCWarning(logDFMBase) << "Failed to open desktop file with gio: g_desktop_app_info_new_from_filename returns NULL. Check PATH maybe?";
+        qCWarning(logDFMBase) << "LocalFileHandler::openFilesByApp: Failed to create GDesktopAppInfo from:"
+                              << desktopFile << "Check if file exists and PATH is correct";
         return false;
     }
 
@@ -354,24 +386,31 @@ bool LocalFileHandler::openFilesByApp(const QList<QUrl> &fileUrls, const QString
 
     QString terminalFlag = QString(g_desktop_app_info_get_string(appInfo, "Terminal"));
     if (terminalFlag == "true") {
+        qCDebug(logDFMBase) << "LocalFileHandler::openFilesByApp: Running terminal application:" << desktopFile;
         QString exec = QString(g_desktop_app_info_get_string(appInfo, "Exec"));
         QStringList args;
         args << "-e" << exec.split(" ").at(0) << filePathsStr;
         QString termPath = defaultTerminalPath();
-        qCDebug(logDFMBase) << termPath << args;
+        qCDebug(logDFMBase) << "LocalFileHandler::openFilesByApp: Terminal command:" << termPath << args;
         ok = QProcess::startDetached(termPath, args);
     } else {
+        qCDebug(logDFMBase) << "LocalFileHandler::openFilesByApp: Launching GUI application:" << desktopFile;
         ok = d->launchApp(desktopFile, filePathsStr);
     }
     g_object_unref(appInfo);
 
     if (ok) {
+        qCInfo(logDFMBase) << "LocalFileHandler::openFilesByApp: Successfully opened files with app:"
+                           << desktopFile << "Files count:" << fileUrls.size();
         // workaround since DTK apps doesn't support the recent file spec.
         // spec: https://www.freedesktop.org/wiki/Specifications/desktop-bookmark-spec/
         // the correct approach: let the app add it to the recent list.
         // addToRecentFile(DUrl::fromLocalFile(filePath), mimetype);
         QString mimetype = d->getFileMimetype(fileUrls.first());
         d->addRecentFile(desktopFile, fileUrls, mimetype);
+    } else {
+        qCWarning(logDFMBase) << "LocalFileHandler::openFilesByApp: Failed to open files with app:"
+                              << desktopFile;
     }
 
     return ok;
@@ -385,24 +424,25 @@ bool LocalFileHandler::openFilesByApp(const QList<QUrl> &fileUrls, const QString
  */
 bool LocalFileHandler::createSystemLink(const QUrl &sourcefile, const QUrl &link)
 {
+    qCDebug(logDFMBase) << "LocalFileHandler::createSystemLink: Creating system link from:" << sourcefile << "to:" << link;
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(sourcefile) };
 
     if (!oper) {
-        qCWarning(logDFMBase) << "create operator failed, url: " << sourcefile;
+        qCCritical(logDFMBase) << "LocalFileHandler::createSystemLink: Failed to create DOperator for:" << sourcefile;
         return false;
     }
 
     bool success = oper->createLink(link);
     if (!success) {
-        qCWarning(logDFMBase) << "create link failed, url: " << sourcefile << " link url: " << link;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::createSystemLink: Failed to create link from:" << sourcefile
+                              << "to:" << link << "Error:" << oper->lastError().errorMsg();
         d->setError(oper->lastError());
-
         return false;
     }
 
-    qCInfo(logDFMBase, "create system link, source file %s, link file %s successed !",
-           sourcefile.path().toStdString().c_str(), link.path().toStdString().c_str());
+    qCInfo(logDFMBase) << "LocalFileHandler::createSystemLink: Successfully created system link from:"
+                       << sourcefile << "to:" << link;
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, link);
 
     return true;
@@ -415,27 +455,35 @@ bool LocalFileHandler::createSystemLink(const QUrl &sourcefile, const QUrl &link
  */
 bool LocalFileHandler::setPermissions(const QUrl &url, QFileDevice::Permissions permissions)
 {
+    qCDebug(logDFMBase) << "LocalFileHandler::setPermissions: Setting permissions for:" << url
+                        << "Permissions:" << QString::number(static_cast<uint16_t>(permissions), 8);
+
     QSharedPointer<DFMIO::DFile> dfile { new DFMIO::DFile(url) };
     if (!dfile) {
-        qCWarning(logDFMBase) << "create file failed, url: " << url;
+        qCCritical(logDFMBase) << "LocalFileHandler::setPermissions: Failed to create DFile for:" << url;
         return false;
     }
 
     // if the `permissions` is invalid, do not set permissions
     // eg. bug-199607: Copy MTP folder to local, folder permissions wrong
     // reason: `dfm-io` uses gio to query the `unix::mode` field to get file permissions, but this field is not available in MTP file
-    if (0 == permissions)
+    if (0 == permissions) {
+        qCDebug(logDFMBase) << "LocalFileHandler::setPermissions: Skipping permission setting for:" << url
+                            << "Permissions value is 0 (likely from MTP or unsupported filesystem)";
         return true;
+    }
 
     bool success = dfile->setPermissions(DFMIO::DFile::Permissions(uint16_t(permissions)));
     if (!success) {
-        qCWarning(logDFMBase) << "set permissions failed, url: " << url;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::setPermissions: Failed to set permissions for:" << url
+                              << "Permissions:" << QString::number(static_cast<uint16_t>(permissions), 8)
+                              << "Error:" << dfile->lastError().errorMsg();
         d->setError(dfile->lastError());
-
         return false;
     }
 
+    qCDebug(logDFMBase) << "LocalFileHandler::setPermissions: Successfully set permissions for:" << url
+                        << "Permissions:" << QString::number(static_cast<uint16_t>(permissions), 8);
     return true;
 }
 
@@ -531,79 +579,105 @@ QString LocalFileHandler::trashFile(const QUrl &url)
  */
 bool LocalFileHandler::deleteFile(const QUrl &url)
 {
+    qCDebug(logDFMBase) << "LocalFileHandler::deleteFile: Deleting file:" << url;
+
     QSharedPointer<DFMIO::DOperator> dOperator { new DFMIO::DOperator(url) };
 
     if (!dOperator) {
-        qCWarning(logDFMBase) << "create file operator failed, url: " << url;
+        qCCritical(logDFMBase) << "LocalFileHandler::deleteFile: Failed to create DOperator for:" << url;
         return false;
     }
 
     bool success = dOperator->deleteFile();
     if (!success) {
-        qCWarning(logDFMBase) << "delete file failed, url: " << url;
-
+        qCWarning(logDFMBase) << "LocalFileHandler::deleteFile: Failed to delete file:" << url
+                              << "Error:" << dOperator->lastError().errorMsg();
         d->setError(dOperator->lastError());
-
         return false;
     }
+
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileDeleted, url);
-    qCWarning(logDFMBase) << "delete file success: " << url;
+    qCWarning(logDFMBase) << "LocalFileHandler::deleteFile: Successfully deleted file:" << url;
 
     return true;
 }
 
 bool LocalFileHandler::deleteFileRecursive(const QUrl &url)
 {
-    qCInfo(logDFMBase) << "Recursive delete " << url;
+    qCInfo(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Starting recursive deletion of:" << url;
 
     if (!url.isValid()) {
-        qCWarning(logDFMBase) << "Invalid URL provided to deleteFileRecursive:" << url;
+        qCWarning(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Invalid URL provided:" << url;
         return false;
     }
 
     if (SystemPathUtil::instance()->isSystemPath(url.toLocalFile())) {
-        qCWarning(logDFMBase) << "Cannot delete system path!!!!!!!!!!!!!!!!!";
+        qCCritical(logDFMBase) << "LocalFileHandler::deleteFileRecursive: CRITICAL - Attempted to delete system path:"
+                               << url << "Operation aborted for safety";
         abort();
     }
 
     FileInfoPointer info { InfoFactory::create<FileInfo>(url) };
     if (!info) {
-        qCWarning(logDFMBase) << "Failed to create FileInfo for:" << url;
+        qCWarning(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Failed to create FileInfo for:" << url;
         return false;
     }
 
     // 首先检查是否是符号链接，如果是则只删除链接本身
     if (info->isAttributes(OptInfoType::kIsSymLink)) {
-        qCInfo(logDFMBase) << "Delete symbolic link: " << url;
+        qCDebug(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Deleting symbolic link:" << url;
         return deleteFile(url);
     }
 
-    if (!info->isAttributes(OptInfoType::kIsDir))
+    if (!info->isAttributes(OptInfoType::kIsDir)) {
+        qCDebug(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Deleting regular file:" << url;
         return deleteFile(url);
+    }
+
+    qCDebug(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Processing directory contents:" << url;
 
     QSharedPointer<DFMIO::DEnumerator> enumerator { new DFMIO::DEnumerator(url) };
     if (!enumerator) {
-        qCWarning(logDFMBase) << "Cannot create enumerator";
+        qCWarning(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Failed to create enumerator for:" << url;
         return false;
     }
 
-    bool succ { false };
+    bool succ { true };
+    int deletedCount = 0;
     while (enumerator->hasNext()) {
         const QUrl &urlNext = enumerator->next();
         info = InfoFactory::create<FileInfo>(urlNext);
         if (!info) {
-            qCWarning(logDFMBase) << "Failed to create FileInfo for:" << urlNext;
+            qCWarning(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Failed to create FileInfo for:" << urlNext;
+            succ = false;
             continue;
         }
 
-        if (info->isAttributes(OptInfoType::kIsDir))
-            succ = deleteFileRecursive(urlNext);
-        else
-            succ = deleteFile(urlNext);
+        bool itemSuccess = false;
+        if (info->isAttributes(OptInfoType::kIsDir)) {
+            itemSuccess = deleteFileRecursive(urlNext);
+        } else {
+            itemSuccess = deleteFile(urlNext);
+        }
+
+        if (itemSuccess) {
+            deletedCount++;
+        } else {
+            succ = false;
+        }
     }
 
-    succ = deleteFile(url);
-    return succ;
+    qCDebug(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Deleted" << deletedCount
+                        << "items from directory:" << url;
+
+    bool dirDeleted = deleteFile(url);
+    if (dirDeleted) {
+        qCInfo(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Successfully completed recursive deletion of:" << url;
+    } else {
+        qCWarning(logDFMBase) << "LocalFileHandler::deleteFileRecursive: Failed to delete directory after clearing contents:" << url;
+    }
+
+    return succ && dirDeleted;
 }
 /*!
  * \brief LocalFileHandler::setFileTime 设置文件的读取和最后修改时间
