@@ -533,7 +533,7 @@ void SyncFileInfo::updateAttributes(const QList<FileInfo::FileInfoAttributeID> &
     auto typeAll = types;
     if (typeAll.isEmpty()) {
         if (isAttributes(OptInfoType::kIsSymLink)) {
-            auto target = d->symLinkTarget();
+            auto target = FileUtils::resolveSymlink(fileUrl());
             if (!target.isEmpty() && target != filePath()) {
                 FileInfoPointer info = InfoFactory::create<FileInfo>(QUrl::fromLocalFile(target));
                 if (info)
@@ -888,6 +888,9 @@ QString SyncFileInfoPrivate::symLinkTarget() const
         symLinkTarget.prepend(currPath);
     }
 
+    if (symLinkTarget.endsWith("/"))
+        symLinkTarget.chop(1);
+
     return symLinkTarget;
 }
 
