@@ -122,16 +122,26 @@ bool PluginManagerPrivate::readPlugins()
  */
 void PluginManagerPrivate::scanfAllPlugin()
 {
-    if (pluginLoadIIDs.isEmpty())
+    if (pluginLoadIIDs.isEmpty()) {
+        qCWarning(logDPF) << "PluginManagerPrivate: no plugin IIDs configured, skipping scan";
         return;
+    }
+
+    qCInfo(logDPF) << "PluginManagerPrivate: starting plugin scan in" << pluginLoadPaths.size() << "paths";
+    int totalScanned = 0;
+    int validPlugins = 0;
 
     for (const QString &path : pluginLoadPaths) {
+        qCDebug(logDPF) << "PluginManagerPrivate: scanning path:" << path;
         QDirIterator dirItera(path, { "*.so" },
                               QDir::Filter::Files,
                               QDirIterator::IteratorFlag::NoIteratorFlags);
 
+        int pathScanned = 0;
         while (dirItera.hasNext()) {
             dirItera.next();
+            totalScanned++;
+            pathScanned++;
             PluginMetaObjectPointer metaObj(new PluginMetaObject);
             const QString &fileName { dirItera.path() + "/" + dirItera.fileName() };
             qCDebug(logDPF) << "scan plugin:" << fileName;
@@ -145,12 +155,20 @@ void PluginManagerPrivate::scanfAllPlugin()
             }
 
             bool isVirtual = dataJson.contains(kVirtualPluginMeta) && dataJson.contains(kVirtualPluginList);
-            if (isVirtual)
+            if (isVirtual) {
+                qCDebug(logDPF) << "PluginManagerPrivate: found virtual plugin:" << fileName;
                 scanfVirtualPlugin(fileName, dataJson);
-            else
+            } else {
+                qCDebug(logDPF) << "PluginManagerPrivate: found real plugin:" << fileName;
                 scanfRealPlugin(metaObj, dataJson);
+            }
+            validPlugins++;
         }
+        qCDebug(logDPF) << "PluginManagerPrivate: scanned" << pathScanned << "files in path:" << path;
     }
+    
+    qCInfo(logDPF) << "PluginManagerPrivate: plugin scan completed - total scanned:" << totalScanned 
+                   << "valid plugins:" << validPlugins << "in read queue:" << readQueue.size();
 }
 
 void PluginManagerPrivate::scanfRealPlugin(PluginMetaObjectPointer metaObj,
@@ -242,6 +260,8 @@ void PluginManagerPrivate::readJsonToMeta(PluginMetaObjectPointer metaObject)
 
 void PluginManagerPrivate::jsonToMeta(PluginMetaObjectPointer metaObject, const QJsonObject &metaData)
 {
+    qCDebug(logDPF) << "PluginManagerPrivate: parsing JSON metadata for plugin:" << metaObject->d->name;
+    
     metaObject->d->version = metaData.value(kPluginVersion).toString();
     metaObject->d->category = metaData.value(kPluginCategory).toString();
     metaObject->d->description = metaData.value(kPluginDescription).toString();
@@ -258,6 +278,7 @@ void PluginManagerPrivate::jsonToMeta(PluginMetaObjectPointer metaObject, const
         depends.pluginName = dependName;
         depends.pluginVersion = dependVersion;
         metaObject->d->depends.append(depends);
+        qCDebug(logDPF) << "PluginManagerPrivate: added dependency:" << dependName << "version:" << dependVersion;
         ++itera;
     }
 
@@ -265,6 +286,8 @@ void PluginManagerPrivate::jsonToMeta(PluginMetaObjectPointer metaObject, const
 
     // QML 组件信息
     QJsonArray &&quickArray = metaData.value(kQuick).toArray();
+    qCDebug(logDPF) << "PluginManagerPrivate: processing" << quickArray.size() << "Quick components for plugin:" << metaObject->d->name;
+    
     for (const auto &quickItr : quickArray) {
         const QJsonObject &quick = quickItr.toObject();
 
@@ -305,7 +328,10 @@ void PluginManagerPrivate::jsonToMeta(PluginMetaObjectPointer metaObject, const
         quickMeta->d->quickParent = quickParent;
 
         metaObject->d->quickMetaList.append(quickMeta);
+        qCDebug(logDPF) << "PluginManagerPrivate: added Quick component:" << id << "url:" << fullPath;
     }
+    
+    qCDebug(logDPF) << "PluginManagerPrivate: JSON metadata parsing completed for plugin:" << metaObject->d->name;
 }
 
 /*!
@@ -489,12 +515,17 @@ bool PluginManagerPrivate::doLoadPlugin(PluginMetaObjectPointer pointer)
         return false;
     }
 
+    qCInfo(logDPF) << "PluginManagerPrivate: starting to load plugin:" << pointer->d->name;
     pointer->d->state = PluginMetaObject::State::kLoading;
 
     if (pointer->isVirtual() && loadedVirtualPlugins.contains(pointer->d->realName)) {
         auto creator = qobject_cast<PluginCreator *>(pointer->d->loader->instance());
-        if (creator)
+        if (creator) {
             pointer->d->plugin = creator->create(pointer->name());
+            qCDebug(logDPF) << "PluginManagerPrivate: created virtual plugin instance for:" << pointer->d->name;
+        } else {
+            qCWarning(logDPF) << "PluginManagerPrivate: failed to get creator for virtual plugin:" << pointer->d->name;
+        }
         pointer->d->state = PluginMetaObject::State::kLoaded;
         qCInfo(logDPF) << "Virtual Plugin: " << pointer->d->name << " has been loaded";
         return true;
@@ -519,14 +550,21 @@ bool PluginManagerPrivate::doLoadPlugin(PluginMetaObjectPointer pointer)
     bool isNullPluginInstance { false };
     if (pointer->isVirtual()) {
         auto creator = qobject_cast<PluginCreator *>(pointer->d->loader->instance());
-        if (creator)
+        if (creator) {
             pointer->d->plugin = creator->create(pointer->name());
-        else
+            qCDebug(logDPF) << "PluginManagerPrivate: created virtual plugin instance:" << pointer->d->name;
+        } else {
             isNullPluginInstance = true;
+            qCWarning(logDPF) << "PluginManagerPrivate: failed to get creator for virtual plugin:" << pointer->d->name;
+        }
     } else {
         pointer->d->plugin = QSharedPointer<Plugin>(qobject_cast<Plugin *>(pointer->d->loader->instance()));
-        if (pointer->d->plugin.isNull())
+        if (pointer->d->plugin.isNull()) {
             isNullPluginInstance = true;
+            qCWarning(logDPF) << "PluginManagerPrivate: failed to get plugin instance for:" << pointer->d->name;
+        } else {
+            qCDebug(logDPF) << "PluginManagerPrivate: got plugin instance for:" << pointer->d->name;
+        }
     }
 
     if (isNullPluginInstance) {
