@@ -97,7 +97,9 @@ bool UserShareHelper::share(const ShareInfo &info)
 
     if (isValidShare(info)) {
         const auto &&name = info.value(ShareInfoKeys::kName).toString();
-        if (name.startsWith("-") || name.endsWith(" ")) {
+        // 是否包含了非法字符：%<>*?|/\\+=;:,\"，且不能以 "-" 和空格开头，或者空格结尾
+        QRegularExpression regex(R"(^(?![ -])[^%<>*?|/\\+=;:,"]*$(?<! ))");
+        if (!regex.match(name).hasMatch()) {
             DialogManagerInstance->showErrorDialog(tr("The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.").arg("%<>*?|/\\+=;:,\""), "");
             return false;
         }
@@ -144,17 +146,19 @@ void UserShareHelper::setSambaPasswd(const QString &userName, const QString &pas
 {
     QString encPass = FileUtils::encryptString(passwd);
     QDBusReply<bool> reply = userShareInter->call(DaemonServiceIFace::kFuncSetPasswd, userName, encPass);
-    bool result = reply.isValid() && reply.error().message().isEmpty();
-    fmInfo() << "Samba password set result :" << result << ",error msg:" << reply.error().message();
+    bool success = reply.isValid() && reply.value();
+    fmInfo() << "Samba password set result:" << success
+             << ", error msg:" << (reply.isValid() ? "none" : reply.error().message());
 
-    Q_EMIT sambaPasswordSet(result);
+    Q_EMIT sambaPasswordSet(success);
 }
 
-void UserShareHelper::removeShareByPath(const QString &path)
+bool UserShareHelper::removeShareByPath(const QString &path)
 {
     const QString &&shareName = shareNameByPath(path);
     if (!shareName.isEmpty())
-        removeShareByShareName(shareName);
+        return removeShareByShareName(shareName);
+    return false;
 }
 
 int UserShareHelper::readPort()
@@ -310,10 +314,10 @@ bool UserShareHelper::canShare(FileInfoPointer info)
     if (!info || !info->isAttributes(OptInfoType::kIsDir) || !info->isAttributes(OptInfoType::kIsReadable))
         return false;
 
-    if (DevProxyMng->isFileOfProtocolMounts(info->pathOf(PathInfoType::kFilePath)))
+    if (DevProxyMng->isFileOfProtocolMounts(info->pathOf(PathInfoType::kCanonicalPath)))
         return false;
 
-    if (info->urlOf(UrlInfoType::kUrl).scheme() == Global::Scheme::kBurn || DevProxyMng->isFileFromOptical(info->pathOf(PathInfoType::kFilePath)))
+    if (info->urlOf(UrlInfoType::kUrl).scheme() == Global::Scheme::kBurn || DevProxyMng->isFileFromOptical(info->pathOf(PathInfoType::kCanonicalPath)))
         return false;
 
     return true;
@@ -344,6 +348,9 @@ void UserShareHelper::readShareInfos(bool sendSignal)
     QDir d(ShareConfig::kShareConfigPath);
     QFileInfoList shareList = d.entryInfoList(QDir::Files | QDir::Hidden);
     for (const auto &fileInfo : shareList) {
+        if (fileInfo.groupId() != SysInfoUtils::getUserId())
+            continue;
+
         QString filePath = fileInfo.absoluteFilePath();
         QFile file(filePath);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -453,17 +460,19 @@ void UserShareHelper::initMonitorPath()
         watcherManager->add(info.value(ShareInfoKeys::kPath).toString());
 }
 
-void UserShareHelper::removeShareByShareName(const QString &name, bool silent)
+bool UserShareHelper::removeShareByShareName(const QString &name, bool silent)
 {
     QDBusReply<bool> reply = userShareInter->asyncCall(DaemonServiceIFace::kFuncCloseShare, name, !silent);
     if (reply.isValid() && reply.value()) {
         fmDebug() << "share closed: " << name;
         runNetCmd(QStringList() << "usershare"
                                 << "delete" << name);
-    } else {
-        fmWarning() << "share close failed: " << name << ", " << reply.error();
-        // TODO(xust) regular user cannot remove the sharing which shared by root user. and should raise an error dialog to notify user.
+        return true;
     }
+
+    fmWarning() << "share close failed: " << name << ", " << reply.error();
+    // TODO(xust) regular user cannot remove the sharing which shared by root user. and should raise an error dialog to notify user.
+    return false;
 }
 
 void UserShareHelper::removeShareWhenShareFolderDeleted(const QString &deletedPath)
@@ -543,7 +552,7 @@ void UserShareHelper::handleErrorWhenShareFailed(int code, const QString &err) c
         return;
     }
 
-    //计算机名称过长会报错
+    // 计算机名称过长会报错
     if (err.contains("gethostname failed") && err.contains("net usershare add: cannot convert name")) {
         DialogManagerInstance->showErrorDialog(tr("Sharing failed"), tr("The computer name is too long"));
         return;
