@@ -25,6 +25,10 @@ void GioEmblemWorker::onProduce(const FileInfoPointer &info)
 {
     Q_ASSERT(qApp->thread() != QThread::currentThread());
 
+    if (!info) {
+        return;  // 添加空指针检查
+    }
+
     const auto &emblems { fetchEmblems(info) };
 
     const QUrl &url = info->urlOf(UrlInfoType::kUrl);
@@ -264,6 +268,16 @@ QList<QIcon> EmblemHelper::gioEmblemIcons(const QUrl &url) const
 
 void EmblemHelper::pending(const FileInfoPointer &info)
 {
+    if (!info)
+        return;
+    
+    const QUrl &url = info->urlOf(UrlInfoType::kUrl);
+    
+    // 避免重复请求同一个URL
+    if (pendingUrls.contains(url))
+        return;
+        
+    pendingUrls.insert(url);
     emit requestProduce(info);
 }
 
@@ -288,6 +302,9 @@ bool EmblemHelper::isExtEmblemProhibited(const FileInfoPointer &info, const QUrl
 
 void EmblemHelper::onEmblemChanged(const QUrl &url, const Product &product)
 {
+    // 从pending集合中移除已处理的URL
+    pendingUrls.remove(url);
+    
     productQueue[url] = product;
     if (product.isEmpty())
         return;
@@ -304,6 +321,7 @@ bool EmblemHelper::onUrlChanged(quint64 windowId, const QUrl &url)
     Q_UNUSED(url);
 
     clearEmblem();
+    pendingUrls.clear();  // 清空pending请求缓存
     emit requestClear();
 
     return false;
