@@ -25,7 +25,6 @@
 #include <dtkwidget_global.h>
 #include <dtkgui_config.h>
 
-#include <QDebug>
 #include <QtConcurrent>
 #include <QCoreApplication>
 
@@ -46,11 +45,16 @@ TrashFileEventReceiver::TrashFileEventReceiver(QObject *parent)
     connect(this, &TrashFileEventReceiver::cleanTrashUrls, this, &TrashFileEventReceiver::onCleanTrashUrls, Qt::QueuedConnection);
     connect(qApp, &QCoreApplication::aboutToQuit, this, [=]() {
         stoped = true;
-        if (trashIterator)
+        if (trashIterator) {
+            fmInfo() << "Cancelling trash iterator on application quit";
             trashIterator->cancel();
+        }
 
         future.waitForFinished();
+        fmInfo() << "TrashFileEventReceiver cleanup completed";
     });
+    
+    fmInfo() << "TrashFileEventReceiver initialized successfully";
 }
 
 JobHandlePointer TrashFileEventReceiver::doMoveToTrash(const quint64 windowId, const QList<QUrl> &sources, const DFMBASE_NAMESPACE::AbstractJobHandler::JobFlags flags,
@@ -59,15 +63,21 @@ JobHandlePointer TrashFileEventReceiver::doMoveToTrash(const quint64 windowId, c
     Q_UNUSED(windowId);
 
     // 源文件是空
-    if (sources.isEmpty())
+    if (sources.isEmpty()) {
+        fmWarning() << "Move to trash operation aborted: source list is empty";
         return nullptr;
+    }
+
+    fmInfo() << "Processing move to trash operation for" << sources.count() << "items";
 
     // 其他插件处理了相应的操作，直接返回
     if (dpfHookSequence->run("dfmplugin_fileoperations", "hook_Operation_MoveToTrash", windowId, sources, flags)) {
+        fmInfo() << "Move to trash operation handled by other plugin";
         return nullptr;
     }
 
     if (SystemPathUtil::instance()->checkContainsSystemPath(sources)) {
+        fmWarning() << "Move to trash operation blocked: contains system path";
         DialogManagerInstance->showDeleteSystemPathWarnDialog(windowId);
         return nullptr;
     }
@@ -85,17 +95,27 @@ JobHandlePointer TrashFileEventReceiver::doMoveToTrash(const quint64 windowId, c
     }
 
     if (nullDirDelete || !FileUtils::fileCanTrash(sourceFirst)) {
-        if (DialogManagerInstance->showDeleteFilesDialog(processedSources, true) != QDialog::Accepted)
+        fmInfo() << "File cannot be moved to trash, will perform direct delete operation:" 
+                 << "nullDirDelete=" << nullDirDelete 
+                 << "canTrash=" << FileUtils::fileCanTrash(sourceFirst);
+        
+        if (DialogManagerInstance->showDeleteFilesDialog(processedSources, true) != QDialog::Accepted) {
+            fmInfo() << "Delete operation cancelled by user";
             return nullptr;
+        }
         handle = copyMoveJob->deletes(processedSources, flags, isInit);
         if (!isInit)
             return handle;
     } else {
+        fmInfo() << "Processing normal move to trash operation";
+        
         // check url permission
         QList<QUrl> urlsCanTrash = processedSources;
         if (!flags.testFlag(AbstractJobHandler::JobFlag::kRevocation) && Application::instance()->genericAttribute(Application::kShowDeleteConfirmDialog).toBool()) {
-            if (DialogManagerInstance->showNormalDeleteConfirmDialog(urlsCanTrash) != QDialog::Accepted)
+            if (DialogManagerInstance->showNormalDeleteConfirmDialog(urlsCanTrash) != QDialog::Accepted) {
+                fmInfo() << "Move to trash operation cancelled by user";
                 return nullptr;
+            }
         }
         handle = copyMoveJob->moveToTrash(urlsCanTrash, flags, isInit);
         if (!isInit)
@@ -103,6 +123,8 @@ JobHandlePointer TrashFileEventReceiver::doMoveToTrash(const quint64 windowId, c
     }
     if (handleCallback)
         handleCallback(handle);
+    
+    fmInfo() << "Move to trash operation completed successfully";
     return handle;
 }
 
@@ -111,14 +133,20 @@ JobHandlePointer TrashFileEventReceiver::doRestoreFromTrash(const quint64 window
 {
     Q_UNUSED(windowId)
 
-    if (sources.isEmpty())
+    if (sources.isEmpty()) {
+        fmWarning() << "Restore from trash operation aborted: source list is empty";
         return nullptr;
+    }
+
+    fmInfo() << "Processing restore from trash operation for" << sources.count() << "items to target:" << target;
 
     JobHandlePointer handle = copyMoveJob->restoreFromTrash(sources, target, flags);
     if (!isInit)
         return handle;
     if (handleCallback)
         handleCallback(handle);
+    
+    fmInfo() << "Restore from trash operation completed successfully";
     return handle;
 }
 
@@ -128,12 +156,18 @@ JobHandlePointer TrashFileEventReceiver::doCopyFromTrash(const quint64 windowId,
 {
     Q_UNUSED(windowId)
 
-    if (sources.isEmpty())
+    if (sources.isEmpty()) {
+        fmWarning() << "Copy from trash operation aborted: source list is empty";
         return nullptr;
+    }
+
+    fmInfo() << "Processing copy from trash operation for" << sources.count() << "items to target:" << target;
 
     JobHandlePointer handle = copyMoveJob->copyFromTrash(sources, target, flags);
     if (handleCallback)
         handleCallback(handle);
+    
+    fmInfo() << "Copy from trash operation completed successfully";
     return handle;
 }
 
@@ -143,16 +177,23 @@ JobHandlePointer TrashFileEventReceiver::doCleanTrash(const quint64 windowId, co
     Q_UNUSED(windowId)
     Q_UNUSED(deleteNoticeType)
 
-    if (stoped)
+    if (stoped) {
+        fmWarning() << "Clean trash operation aborted: receiver is stopping";
         return nullptr;
+    }
+
+    fmInfo() << "Processing clean trash operation for" << sources.count() << "items, showDialog:" << showDelet;
 
     if (!sources.isEmpty() && showDelet) {
         // Show delete files dialog
-        if (DialogManagerInstance->showDeleteFilesDialog(sources) != QDialog::Accepted)
+        if (DialogManagerInstance->showDeleteFilesDialog(sources) != QDialog::Accepted) {
+            fmInfo() << "Clean trash operation cancelled by user";
             return nullptr;
+        }
     }
 
     if (sources.isEmpty()) {
+        fmInfo() << "Starting async trash count operation";
         future = QtConcurrent::run([windowId, deleteNoticeType, handleCallback]() {
             if (handleCallback)
                 return instance()->countTrashFile(windowId, deleteNoticeType, handleCallback);
@@ -162,9 +203,13 @@ JobHandlePointer TrashFileEventReceiver::doCleanTrash(const quint64 windowId, co
     }
 
     if (!showDelet) {
-        if (DialogManagerInstance->showClearTrashDialog(static_cast<quint64>(sources.length())) != QDialog::Accepted) return nullptr;
+        if (DialogManagerInstance->showClearTrashDialog(static_cast<quint64>(sources.length())) != QDialog::Accepted) {
+            fmInfo() << "Clear trash operation cancelled by user";
+            return nullptr;
+        }
     }
 
+    fmInfo() << "Playing trash empty sound effect";
     DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_EmptyTrash);
 
     QList<QUrl> urls = std::move(sources);
@@ -175,30 +220,47 @@ JobHandlePointer TrashFileEventReceiver::doCleanTrash(const quint64 windowId, co
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kCleanTrashType, handle);
     if (handleCallback)
         handleCallback(handle);
+    
+    fmInfo() << "Clean trash operation completed successfully";
     return handle;
 }
 
 void TrashFileEventReceiver::countTrashFile(const quint64 windowId, const DFMBASE_NAMESPACE::AbstractJobHandler::DeleteDialogNoticeType deleteNoticeType,
                                             AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
-    if (stoped)
+    if (stoped) {
+        fmWarning() << "Count trash file operation aborted: receiver is stopping";
         return;
+    }
+    
+    fmInfo() << "Starting trash file enumeration";
     DFMIO::DEnumerator enumerator(FileUtils::trashRootUrl());
     QList<QUrl> allFilesList;
+    int processedCount = 0;
+    
     while (enumerator.hasNext()) {
-        if (stoped)
+        if (stoped) {
+            fmWarning() << "Count trash file operation interrupted by stop signal";
             return;
+        }
         auto url = FileUtils::bindUrlTransform(enumerator.next());
-        if (!allFilesList.contains(url))
+        if (!allFilesList.contains(url)) {
             allFilesList.append(url);
+            processedCount++;
+        }
     }
 
-    if (stoped)
+    if (stoped) {
+        fmWarning() << "Count trash file operation interrupted after processing" << processedCount << "files";
         return;
+    }
 
-    if (allFilesList.isEmpty())
+    if (allFilesList.isEmpty()) {
+        fmInfo() << "Trash is empty, no files to process";
         return;
+    }
 
+    fmInfo() << "Trash enumeration completed, found" << allFilesList.count() << "files";
     emit cleanTrashUrls(windowId, allFilesList, deleteNoticeType, handleCallback);
 }
 
@@ -211,6 +273,7 @@ TrashFileEventReceiver *TrashFileEventReceiver::instance()
 void TrashFileEventReceiver::handleOperationMoveToTrash(const quint64 windowId, const QList<QUrl> sources, const AbstractJobHandler::JobFlag flags,
                                                         DFMBASE_NAMESPACE::AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
+    fmInfo() << "Handling move to trash operation, window ID:" << windowId << "items count:" << sources.count();
     auto handle = doMoveToTrash(windowId, sources, flags, handleCallback);
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kMoveToTrashType, handle);
 }
@@ -219,6 +282,7 @@ void TrashFileEventReceiver::handleOperationRestoreFromTrash(const quint64 windo
                                                              const AbstractJobHandler::JobFlag flags,
                                                              DFMBASE_NAMESPACE::AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
+    fmInfo() << "Handling restore from trash operation, window ID:" << windowId << "items count:" << sources.count();
     auto handle = doRestoreFromTrash(windowId, sources, target, flags, handleCallback);
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kRestoreType, handle);
 }
@@ -226,6 +290,7 @@ void TrashFileEventReceiver::handleOperationRestoreFromTrash(const quint64 windo
 void TrashFileEventReceiver::handleOperationCleanTrash(const quint64 windowId, const QList<QUrl> sources, const AbstractJobHandler::DeleteDialogNoticeType deleteNoticeType,
                                                        DFMBASE_NAMESPACE::AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
+    fmInfo() << "Handling clean trash operation, window ID:" << windowId << "items count:" << sources.count();
     doCleanTrash(windowId, sources, deleteNoticeType, handleCallback);
 }
 
@@ -236,6 +301,7 @@ void TrashFileEventReceiver::handleOperationMoveToTrash(const quint64 windowId,
                                                         const QVariant custom,
                                                         DFMBASE_NAMESPACE::AbstractJobHandler::OperatorCallback callback)
 {
+    fmInfo() << "Handling move to trash operation with callback, window ID:" << windowId << "items count:" << sources.count();
 
     JobHandlePointer handle = doMoveToTrash(windowId, sources, flags, handleCallback);
     if (callback) {
@@ -244,6 +310,7 @@ void TrashFileEventReceiver::handleOperationMoveToTrash(const quint64 windowId,
         args->insert(AbstractJobHandler::CallbackKey::kJobHandle, QVariant::fromValue(handle));
         args->insert(AbstractJobHandler::CallbackKey::kCustom, custom);
         callback(args);
+        fmInfo() << "Custom callback executed for move to trash operation";
     }
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kMoveToTrashType, handle);
 }
@@ -255,6 +322,8 @@ void TrashFileEventReceiver::handleOperationRestoreFromTrash(const quint64 windo
                                                              const QVariant custom,
                                                              DFMBASE_NAMESPACE::AbstractJobHandler::OperatorCallback callback)
 {
+    fmInfo() << "Handling restore from trash operation with callback, window ID:" << windowId << "items count:" << sources.count();
+    
     JobHandlePointer handle = doRestoreFromTrash(windowId, sources, target, flags, handleCallback);
     if (callback) {
         AbstractJobHandler::CallbackArgus args(new QMap<AbstractJobHandler::CallbackKey, QVariant>);
@@ -262,6 +331,7 @@ void TrashFileEventReceiver::handleOperationRestoreFromTrash(const quint64 windo
         args->insert(AbstractJobHandler::CallbackKey::kJobHandle, QVariant::fromValue(handle));
         args->insert(AbstractJobHandler::CallbackKey::kCustom, custom);
         callback(args);
+        fmInfo() << "Custom callback executed for restore from trash operation";
     }
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kRestoreType, handle);
 }
@@ -270,6 +340,8 @@ void TrashFileEventReceiver::handleOperationCleanTrash(const quint64 windowId, c
                                                        DFMBASE_NAMESPACE::AbstractJobHandler::OperatorHandleCallback handleCallback,
                                                        const QVariant custom, AbstractJobHandler::OperatorCallback callback)
 {
+    fmInfo() << "Handling clean trash operation with callback, window ID:" << windowId << "items count:" << sources.count();
+    
     JobHandlePointer handle = doCleanTrash(windowId, sources, AbstractJobHandler::DeleteDialogNoticeType::kEmptyTrash, handleCallback);
     if (callback) {
         AbstractJobHandler::CallbackArgus args(new QMap<AbstractJobHandler::CallbackKey, QVariant>);
@@ -277,6 +349,7 @@ void TrashFileEventReceiver::handleOperationCleanTrash(const quint64 windowId, c
         args->insert(AbstractJobHandler::CallbackKey::kJobHandle, QVariant::fromValue(handle));
         args->insert(AbstractJobHandler::CallbackKey::kCustom, custom);
         callback(args);
+        fmInfo() << "Custom callback executed for clean trash operation";
     }
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kCleanTrashType, handle);
 }
@@ -285,6 +358,7 @@ void TrashFileEventReceiver::handleOperationCopyFromTrash(const quint64 windowId
                                                           const AbstractJobHandler::JobFlag flags,
                                                           DFMBASE_NAMESPACE::AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
+    fmInfo() << "Handling copy from trash operation, window ID:" << windowId << "items count:" << sources.count();
     auto handle = doCopyFromTrash(windowId, sources, target, flags, handleCallback);
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kRestoreType, handle);
 }
@@ -296,6 +370,8 @@ void TrashFileEventReceiver::handleOperationCopyFromTrash(const quint64 windowId
                                                           const QVariant custom,
                                                           AbstractJobHandler::OperatorCallback callback)
 {
+    fmInfo() << "Handling copy from trash operation with callback, window ID:" << windowId << "items count:" << sources.count();
+    
     JobHandlePointer handle = doCopyFromTrash(windowId, sources, target, flags, handleCallback);
     if (callback) {
         AbstractJobHandler::CallbackArgus args(new QMap<AbstractJobHandler::CallbackKey, QVariant>);
@@ -303,29 +379,46 @@ void TrashFileEventReceiver::handleOperationCopyFromTrash(const quint64 windowId
         args->insert(AbstractJobHandler::CallbackKey::kJobHandle, QVariant::fromValue(handle));
         args->insert(AbstractJobHandler::CallbackKey::kCustom, custom);
         callback(args);
+        fmInfo() << "Custom callback executed for copy from trash operation";
     }
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kRestoreType, handle);
 }
 
 void TrashFileEventReceiver::handleSaveRedoOpt(const QString &token, const bool moreThanZero)
 {
+    fmInfo() << "Processing save redo operation for token:" << token << "moreThanZero:" << moreThanZero;
+    
     QVariantMap ret;
     {
         QMutexLocker lk(&undoLock);
-        if (!undoOpts.contains(token))
+        if (!undoOpts.contains(token)) {
+            fmWarning() << "Token not found in undo operations:" << token;
             return;
+        }
         ret = undoOpts.take(token);
     }
-    if (ret.isEmpty())
+    if (ret.isEmpty()) {
+        fmWarning() << "Empty undo operation data for token:" << token;
         return;
+    }
+    
     GlobalEventType undoEventType = static_cast<GlobalEventType>(ret.value("undoevent").value<uint16_t>());
     QList<QUrl> undoSources = QUrl::fromStringList(ret.value("undosources").toStringList());
     QList<QUrl> undoTargets = QUrl::fromStringList(ret.value("undotargets").toStringList());
     GlobalEventType redoEventType = static_cast<GlobalEventType>(ret.value("redoevent").value<uint16_t>());
     QList<QUrl> redoSources = QUrl::fromStringList(ret.value("redosources").toStringList());
     QList<QUrl> redoTargets = QUrl::fromStringList(ret.value("redotargets").toStringList());
-    if (redoEventType == GlobalEventType::kTouchFile && moreThanZero)
+    
+    if (redoEventType == GlobalEventType::kTouchFile && moreThanZero) {
+        fmInfo() << "Skipping touch file redo operation due to size constraint";
         return;
+    }
+    
+    fmInfo() << "Saving redo operation: undoType=" << static_cast<int>(undoEventType) 
+             << "redoType=" << static_cast<int>(redoEventType)
+             << "undoSources=" << undoSources.count() 
+             << "redoSources=" << redoSources.count();
+    
     // save operation by dbus
     QVariantMap values;
     values.insert("undoevent", QVariant::fromValue(static_cast<uint16_t>(redoEventType)));
@@ -335,6 +428,8 @@ void TrashFileEventReceiver::handleSaveRedoOpt(const QString &token, const bool
     values.insert("redosources", QUrl::toStringList(undoSources));
     values.insert("redotargets", QUrl::toStringList(undoTargets));
     dpfSignalDispatcher->publish(GlobalEventType::kSaveRedoOperator, values);
+    
+    fmInfo() << "Redo operation saved successfully";
 }
 
 void TrashFileEventReceiver::handleOperationUndoMoveToTrash(const quint64 windowId,
@@ -343,44 +438,66 @@ void TrashFileEventReceiver::handleOperationUndoMoveToTrash(const quint64 window
                                                             AbstractJobHandler::OperatorHandleCallback handleCallback,
                                                             const QVariantMap &op)
 {
+    fmInfo() << "Processing undo move to trash operation, window ID:" << windowId << "items count:" << sources.count();
+    
     auto handle = doMoveToTrash(windowId, sources, flags, handleCallback, false);
 
-    if (!handle)
+    if (!handle) {
+        fmWarning() << "Failed to create job handle for undo move to trash operation";
         return;
+    }
+    
     connect(handle.get(), &AbstractJobHandler::requestSaveRedoOperation, this,
             &TrashFileEventReceiver::handleSaveRedoOpt);
     {
         QMutexLocker lk(&undoLock);
-        undoOpts.insert(QString::number(quintptr(handle.get()), 16), op);
+        QString token = QString::number(quintptr(handle.get()), 16);
+        undoOpts.insert(token, op);
+        fmInfo() << "Stored undo operation data with token:" << token;
     }
     copyMoveJob->initArguments(handle);
     if (handleCallback)
         handleCallback(handle);
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kMoveToTrashType, handle);
+    
+    fmInfo() << "Undo move to trash operation setup completed";
 }
 
 void TrashFileEventReceiver::handleOperationUndoRestoreFromTrash(const quint64 windowId, const QList<QUrl> &sources, const QUrl &target, const AbstractJobHandler::JobFlag flags, AbstractJobHandler::OperatorHandleCallback handleCallback, const QVariantMap &op)
 {
+    fmInfo() << "Processing undo restore from trash operation, window ID:" << windowId << "items count:" << sources.count();
+    
     auto handle = doRestoreFromTrash(windowId, sources, target, flags, handleCallback, false);
-    if (!handle)
+    if (!handle) {
+        fmWarning() << "Failed to create job handle for undo restore from trash operation";
         return;
+    }
+    
     connect(handle.get(), &AbstractJobHandler::requestSaveRedoOperation, this,
             &TrashFileEventReceiver::handleSaveRedoOpt);
     {
         QMutexLocker lk(&undoLock);
-        undoOpts.insert(QString::number(quintptr(handle.get()), 16), op);
+        QString token = QString::number(quintptr(handle.get()), 16);
+        undoOpts.insert(token, op);
+        fmInfo() << "Stored undo restore operation data with token:" << token;
     }
     copyMoveJob->initArguments(handle);
     if (handleCallback)
         handleCallback(handle);
     FileOperationsEventHandler::instance()->handleJobResult(AbstractJobHandler::JobType::kRestoreType, handle);
+    
+    fmInfo() << "Undo restore from trash operation setup completed";
 }
 
 JobHandlePointer TrashFileEventReceiver::onCleanTrashUrls(const quint64 windowId, const QList<QUrl> &sources,
                                                           const AbstractJobHandler::DeleteDialogNoticeType deleteNoticeType,
                                                           AbstractJobHandler::OperatorHandleCallback handleCallback)
 {
-    if (stoped)
+    if (stoped) {
+        fmWarning() << "Clean trash URLs operation aborted: receiver is stopping";
         return nullptr;
+    }
+    
+    fmInfo() << "Executing clean trash URLs operation for" << sources.count() << "items";
     return doCleanTrash(windowId, sources, deleteNoticeType, handleCallback, false);
 }
