@@ -17,12 +17,12 @@
 
 #include <dfm-base/dfm_global_defines.h>
 #include <dfm-base/base/schemefactory.h>
-#include <dfm-base/base/device/deviceutils.h>
 #include <dfm-base/utils/dialogmanager.h>
 #include <dfm-base/utils/clipboard.h>
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/utils/systempathutil.h>
 #include <dfm-base/utils/universalutils.h>
+#include <dfm-base/utils/protocolutils.h>
 #include <dfm-base/file/local/desktopfileinfo.h>
 
 #include <dfm-framework/dpf.h>
@@ -275,12 +275,14 @@ QStringList TagManager::getTagsByUrls(const QList<QUrl> &urls) const
 {
     // single path:  get all tags of path
     // mult paths:  get same tags of paths
-
     if (urls.isEmpty())
         return {};
 
+    QList<QUrl> realUrls;
+    UniversalUtils::urlsTransformToLocal(urls, &realUrls);
+
     QStringList paths;
-    for (const auto &url : TagHelper::commonUrls(urls)) {
+    for (const auto &url : TagHelper::commonUrls(realUrls)) {
         paths.append(url.path());
     }
 
@@ -301,13 +303,15 @@ QStringList TagManager::getFilesByTag(const QString &tag)
 
 bool TagManager::setTagsForFiles(const QStringList &tags, const QList<QUrl> &files)
 {
-
     // if tags is empty means delete all files's tags
     if (files.isEmpty())
         return false;
 
+    QList<QUrl> realUrls;
+    UniversalUtils::urlsTransformToLocal(files, &realUrls);
+
     // set tags for mult files
-    QStringList mutualTagNames = TagManager::instance()->getTagsByUrls(files);
+    QStringList mutualTagNames = TagManager::instance()->getTagsByUrls(realUrls);
     // for deleting.
     QStringList dirtyTagNames;
     for (const QString &tag : mutualTagNames)
@@ -316,9 +320,9 @@ bool TagManager::setTagsForFiles(const QStringList &tags, const QList<QUrl> &fil
 
     bool result = false;
     if (!dirtyTagNames.isEmpty())
-        result = TagManager::instance()->removeTagsOfFiles(dirtyTagNames, files) || result;
+        result = TagManager::instance()->removeTagsOfFiles(dirtyTagNames, realUrls) || result;
 
-    for (const QUrl &url : TagHelper::commonUrls(files)) {
+    for (const QUrl &url : TagHelper::commonUrls(realUrls)) {
         QStringList tagsOfFile = TagManager::instance()->getTagsByUrls({ url });
         QStringList newTags;
 
@@ -338,9 +342,12 @@ bool TagManager::setTagsForFiles(const QStringList &tags, const QList<QUrl> &fil
 
 bool TagManager::addTagsForFiles(const QList<QString> &tags, const QList<QUrl> &files)
 {
+
     if (tags.isEmpty() || files.isEmpty())
         return false;
 
+    QList<QUrl> urls;
+    UniversalUtils::urlsTransformToLocal(files, &urls);
     // tag --- color
     QMap<QString, QVariant> tagWithColor {};
     for (const QString &tagName : tags) {
@@ -352,7 +359,7 @@ bool TagManager::addTagsForFiles(const QList<QString> &tags, const QList<QUrl> &
     QVariant checkTagResult { TagProxyHandleIns->addTags(tagWithColor) };
     if (checkTagResult.toBool()) {
         QVariantMap infos;
-        for (const auto &f : TagHelper::commonUrls(files))
+        for (const auto &f : TagHelper::commonUrls(urls))
             infos[f.path()] = QVariant(tags);
 
         if (TagProxyHandleIns->addTagsForFiles(infos))
@@ -370,9 +377,12 @@ bool TagManager::removeTagsOfFiles(const QList<QString> &tags, const QList<QUrl>
     if (tags.isEmpty() || files.isEmpty())
         return false;
 
+    QList<QUrl> urls;
+    UniversalUtils::urlsTransformToLocal(files, &urls);
+
     QMap<QString, QVariant> fileWithTag;
 
-    for (const QUrl &url : TagHelper::commonUrls(files)) {
+    for (const QUrl &url : TagHelper::commonUrls(urls)) {
         fileWithTag[UrlRoute::urlToPath(url)] = QVariant(tags);
     }
 
@@ -432,15 +442,6 @@ void TagManager::deleteTags(const QStringList &tags)
     }
 }
 
-void TagManager::deleteFiles(const QList<QUrl> &urls)
-{
-    QStringList paths;
-    for (const auto &temp : TagHelper::commonUrls(urls))
-        paths.append(temp.toString());
-
-    this->deleteTagData(paths, DeleteOpts::kFiles);
-}
-
 bool TagManager::changeTagColor(const QString &tagName, const QString &newTagColor)
 {
     if (tagName.isEmpty() || newTagColor.isEmpty())
@@ -528,7 +529,7 @@ bool TagManager::localFileCanTagFilter(const FileInfoPointer &info) const
             return desktopInfo->canTag();
     }
 
-    if (DeviceUtils::isSamba(url))
+    if (ProtocolUtils::isSMBFile(url))
         return false;
 
     return !SystemPathUtil::instance()->isSystemPath(filePath);
@@ -571,7 +572,7 @@ void TagManager::contenxtMenuHandle(quint64 windowId, const QUrl &url, const QPo
 
     // tag action
     menu->addAction(QObject::tr("Rename"), [url, windowId]() {
-        dpfSlotChannel->push("dfmplugin_sidebar", "slot_Item_TriggerEdit", windowId, url);
+        QTimer::singleShot(200, [url, windowId] { dpfSlotChannel->push("dfmplugin_sidebar", "slot_Item_TriggerEdit", windowId, url); });
     });
 
     menu->addAction(QObject::tr("Remove"), [url]() {
