@@ -424,6 +424,10 @@ bool CollectionItemDelegate::isThumnailIconIndex(const QModelIndex &index) const
 
     FileInfoPointer info { parent()->model()->fileInfo(index) };
     if (info) {
+        // appimage 不显示缩略图底板
+        if (info->nameOf(NameInfoType::kMimeTypeName) == Global::Mime::kTypeAppAppimage)
+            return false;
+
         const auto &attribute { info->extendAttributes(ExtInfoType::kFileThumbnail) };
         if (attribute.isValid() && !attribute.value<QIcon>().isNull())
             return true;
@@ -822,7 +826,10 @@ QRect CollectionItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, co
 
     // 使用QRectF和drawPixmap的重载版本来正确处理缩放
     QRect targetRect(x, y, w, h);
+    painter->save();
+    painter->setRenderHint(QPainter::SmoothPixmapTransform, true);
     painter->drawPixmap(targetRect, px, px.rect());
+    painter->restore();
 
     return targetRect;
 }
