@@ -25,6 +25,7 @@
 #include <dfm-base/base/configs/settingbackend.h>
 #include <dfm-base/base/configs/dconfig/dconfigmanager.h>
 #include <dfm-base/utils/dialogmanager.h>
+#include <dfm-base/utils/viewdefines.h>
 
 using CreateTopWidgetCallback = std::function<QWidget *()>;
 using ShowTopWidgetCallback = std::function<bool(QWidget *, const QUrl &)>;
@@ -35,20 +36,22 @@ Q_DECLARE_METATYPE(QString *);
 Q_DECLARE_METATYPE(QVariant *)
 
 DFMBASE_USE_NAMESPACE
+DFMGLOBAL_USE_NAMESPACE
+
 namespace dfmplugin_search {
-DFM_LOG_REISGER_CATEGORY(DPSEARCH_NAMESPACE)
+DFM_LOG_REGISTER_CATEGORY(DPSEARCH_NAMESPACE)
 
 void Search::initialize()
 {
     UrlRoute::regScheme(SearchHelper::scheme(), "/", {}, true, tr("Search"));
-    //注册Scheme为"search"的扩展的文件信息
+    // 注册Scheme为"search"的扩展的文件信息
     InfoFactory::regClass<SearchFileInfo>(SearchHelper::scheme());
     DirIteratorFactory::regClass<SearchDirIterator>(SearchHelper::scheme());
     WatcherFactory::regClass<SearchFileWatcher>(SearchHelper::scheme(),
                                                 WatcherFactory::RegOpts::kNoCache);
 
     // must inited in main thread
-    TextIndexClient::instance()->checkService();
+    TextIndexClient::instance();
 
     bindEvents();
     bindWindows();
@@ -83,6 +86,8 @@ void Search::regSearchCrumbToTitleBar()
 {
     QVariantMap property;
     property["Property_Key_KeepAddressBar"] = true;
+    property[ViewCustomKeys::kSupportTreeMode] = false;
+    property[ViewCustomKeys::kAllowChangeListHeight] = false;
     dpfSlotChannel->push("dfmplugin_titlebar", "slot_Custom_Register", SearchHelper::scheme(), property);
     dpfHookSequence->follow("dfmplugin_titlebar", "hook_Crumb_RedirectUrl",
                             SearchHelper::instance(), &SearchHelper::crumbRedirectUrl);
@@ -96,8 +101,16 @@ void Search::regSearchToWorkspace()
 {
     dpfSlotChannel->push("dfmplugin_workspace", "slot_RegisterFileView", SearchHelper::scheme());
     dpfSlotChannel->push("dfmplugin_workspace", "slot_RegisterMenuScene", SearchHelper::scheme(), SearchMenuCreator::name());
-    dpfSlotChannel->push("dfmplugin_workspace", "slot_View_SetDefaultViewMode", SearchHelper::scheme(), Global::ViewMode::kListMode);
-    dpfSlotChannel->push("dfmplugin_workspace", "slot_NotSupportTreeView", SearchHelper::scheme());
+    dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_RegisterLoadStrategy", SearchHelper::scheme(), DFMGLOBAL_NAMESPACE::DirectoryLoadStrategy::kPreserve);
+    dpfSlotChannel->push("dfmplugin_workspace", "slot_RegisterFocusFileViewDisabled", SearchHelper::scheme());
+
+    QVariantMap propertise {
+        { DFMGLOBAL_NAMESPACE::ViewCustomKeys::kSupportTreeMode, false },
+        { DFMGLOBAL_NAMESPACE::ViewCustomKeys::kDefaultViewMode, static_cast<int>(Global::ViewMode::kListMode) },
+        { DFMGLOBAL_NAMESPACE::ViewCustomKeys::kAllowChangeListHeight, false },
+        { DFMGLOBAL_NAMESPACE::ViewCustomKeys::kDefaultListHeight, ViewDefines().listHeightCount() - 1 }
+    };
+    dpfSlotChannel->push("dfmplugin_workspace", "slot_View_SetCustomViewProperty", SearchHelper::scheme(), propertise);
 
     CreateTopWidgetCallback createCallback { []() { return new AdvanceSearchBar(); } };
     ShowTopWidgetCallback showCallback { SearchHelper::showTopWidget };
@@ -121,31 +134,6 @@ void Search::regSearchSettingConfig()
         fmWarning() << "cannot regist dconfig of search plugin:" << err;
 
     SettingJsonGenerator::instance()->addGroup(SearchSettings::kGroupSearch, tr("Search"));
-    if (SearchHelper::anythingInterface().isValid()) {
-        SettingJsonGenerator::instance()->addCheckBoxConfig(SearchSettings::kIndexInternal,
-                                                            tr("Auto index internal disk"),
-                                                            true);
-        SettingBackend::instance()->addSettingAccessor(
-                SearchSettings::kIndexInternal,
-                []() {
-                    return SearchHelper::anythingInterface().property("autoIndexInternal");
-                },
-                [](const QVariant &val) {
-                    SearchHelper::anythingInterface().setProperty("autoIndexInternal", val);
-                });
-
-        SettingJsonGenerator::instance()->addCheckBoxConfig(SearchSettings::kIndexExternal,
-                                                            tr("Index external storage device after connected to computer"),
-                                                            false);
-        SettingBackend::instance()->addSettingAccessor(
-                SearchSettings::kIndexExternal,
-                []() {
-                    return SearchHelper::anythingInterface().property("autoIndexExternal");
-                },
-                [](const QVariant &val) {
-                    SearchHelper::anythingInterface().setProperty("autoIndexExternal", val);
-                });
-    }
 
     QString textIndexKey { SearchSettings::kFulltextSearch };
     DialogManager::instance()->registerSettingWidget("checkBoxWidthTextIndex", &SearchHelper::createCheckBoxWidthTextIndex);
@@ -154,9 +142,7 @@ void Search::regSearchSettingConfig()
                                                   { "text", tr("Full-Text search") },
                                                   { "type", "checkBoxWidthTextIndex" },
                                                   { "default", false } });
-    SettingJsonGenerator::instance()->addCheckBoxConfig(SearchSettings::kDisplaySearchHistory,
-                                                        tr("Display search history"),
-                                                        true);
+
     SettingBackend::instance()->addSettingAccessor(
             SearchSettings::kFulltextSearch,
             []() {
@@ -169,25 +155,6 @@ void Search::regSearchSettingConfig()
                                                      DConfig::kEnableFullTextSearch,
                                                      val);
             });
-
-    SettingBackend::instance()->addSettingAccessor(
-            SearchSettings::kDisplaySearchHistory,
-            []() {
-                return DConfigManager::instance()->value(DConfig::kSearchCfgPath,
-                                                         DConfig::kDisplaySearchHistory,
-                                                         true);
-            },
-            [](const QVariant &val) {
-                DConfigManager::instance()->setValue(DConfig::kSearchCfgPath,
-                                                     DConfig::kDisplaySearchHistory,
-                                                     val);
-            });
-    SettingJsonGenerator::instance()->addConfig(SearchSettings::kClearSearchHistory,
-                                                { { "key", "04_clear_search_history" },
-                                                  { "desc", tr("Clear dde-file-manager Search Records") },
-                                                  { "text", tr("Clean up") },
-                                                  { "type", "pushButton" },
-                                                  { "trigger", QVariant(Application::kClearSearchHistory) } });
 }
 
 void Search::bindEvents()
@@ -211,8 +178,6 @@ void Search::bindEvents()
                                    SearchEventReceiverIns, &SearchEventReceiver::handleStopSearch);
     dpfSignalDispatcher->subscribe("dfmplugin_titlebar", "signal_FilterView_Show",
                                    SearchEventReceiverIns, &SearchEventReceiver::handleShowAdvanceSearchBar);
-    dpfSignalDispatcher->subscribe(GlobalEventType::kChangeCurrentUrl,
-                                   SearchEventReceiverIns, &SearchEventReceiver::handleUrlChanged);
     dpfSignalDispatcher->subscribe("dfmplugin_titlebar", "signal_InputAdddressStr_Check",
                                    SearchEventReceiverIns, &SearchEventReceiver::handleAddressInputStr);
 
