@@ -36,8 +36,10 @@ void travers_prehandler::networkAccessPrehandler(quint64 winId, const QUrl &url,
                                                   Global::Scheme::kNfs,
                                                   Global::Scheme::kDav,
                                                   Global::Scheme::kDavs };
-    if (!kSupportedSchemes.contains(scheme))
+    if (!kSupportedSchemes.contains(scheme)) {
+        fmDebug() << "Scheme not supported for network access:" << scheme;
         return;
+    }
 
     // the mounted source must be the TOP dir.
     // if smb://1.2.3.4/top/subdir is passed in, the param passed to mount function must be smb://1.2.3.4/top
@@ -63,11 +65,16 @@ void travers_prehandler::networkAccessPrehandler(quint64 winId, const QUrl &url,
     }
 
     auto onMountFailed = [url, origUrl](const dfmmount::OperationErrorInfo &err) {
+        fmCritical() << "Mount operation failed for URL:" << url.toString()
+                     << "error code:" << err.code << "error message:" << err.message;
+
         DialogManager::instance()->showErrorDialogWhenOperateDeviceFailed(DialogManager::kMount, err);
         // remove from history when mount failed.
         dpfSlotChannel->push("dfmplugin_titlebar", "slot_ServerDialog_RemoveHistory", url.toString());
-        if (!origUrl.isEmpty())
+        if (!origUrl.isEmpty()) {
             dpfSlotChannel->push("dfmplugin_titlebar", "slot_ServerDialog_RemoveHistory", origUrl);
+            fmDebug() << "Removed both original and decoded URLs from history";
+        }
     };
 
     static QString kRecordFilePath = QString("/tmp/dfm_smb_mount_%1.ini").arg(getuid());
@@ -75,8 +82,10 @@ void travers_prehandler::networkAccessPrehandler(quint64 winId, const QUrl &url,
     static QRegularExpression kRegx { "/|\\.|:" };
     auto recordSubPath = [](const QString &smbRoot, const QString &subPath) {
         QFile record(kRecordFilePath);
-        if (!record.exists() && record.open(QIODevice::NewOnly))
+        if (!record.exists() && record.open(QIODevice::NewOnly)) {
             record.close();
+            fmDebug() << "Created new record file:" << kRecordFilePath;
+        }
         auto key(smbRoot);
         key = key.replace(kRegx, "_");
         QSettings sets(kRecordFilePath, QSettings::IniFormat);
@@ -124,6 +133,8 @@ void travers_prehandler::smbAccessPrehandler(quint64 winId, const QUrl &url, std
             dpfSlotChannel->push("dfmplugin_titlebar", "slot_Navigator_Backward", winId);   // if failed/cancelled, back to previous page.
             return;
         }
+    } else {
+        fmDebug() << "Target host is not local, skipping service validation:" << targetHost;
     }
 
     QTimer::singleShot(100, qApp, [=] { networkAccessPrehandler(winId, url, after); });
@@ -167,13 +178,20 @@ void travers_prehandler::onSmbRootMounted(const QString &mountSource, Handler af
     if (after)
         after();
 
-    if (!ProtocolDeviceDisplayManager::instance()->isShowOfflineItem())
-        return;
-    if (ProtocolDeviceDisplayManager::instance()->displayMode() != SmbDisplayMode::kAggregation)
+    if (!ProtocolDeviceDisplayManager::instance()->isShowOfflineItem()) {
+        fmDebug() << "Show offline items is disabled, skipping virtual entry processing";
         return;
+    }
 
-    if (QUrl(mountSource).host().isEmpty())
+    if (ProtocolDeviceDisplayManager::instance()->displayMode() != SmbDisplayMode::kAggregation) {
+        fmDebug() << "Display mode is not aggregation, skipping virtual entry processing";
         return;
+    }
+
+    if (QUrl(mountSource).host().isEmpty()) {
+        fmWarning() << "Mount source has empty host, cannot process virtual entry:" << mountSource;
+        return;
+    }
 
     fmDebug() << "do cache root entry" << mountSource;
     VirtualEntryDbHandler::instance()->saveData(VirtualEntryData(mountSource));
