@@ -85,12 +85,13 @@ void ConnectToServerDialog::onButtonClicked(const int &index)
     // connect to server
     if (index == kConnectButton) {
         if (serverComboBox->currentText().isEmpty()) {
+            fmWarning() << "Connect attempt with empty server address";
             close();
             return;
         }
 
         QString url = getCurrentUrlString();
-        fmInfo() << "try connecting" << url;
+        fmInfo() << "Attempting to connect to server:" << url;
         updateCollections(url, false);
 
         const QString &currentDir = QDir::currentPath();
@@ -249,6 +250,7 @@ void ConnectToServerDialog::initServerDatas()
 
         QUrl url(processedUrl);
         if (!expectedSchemes.contains(url.scheme()) || url.host().isEmpty()) {
+            fmDebug() << "Skipping invalid URL in history:" << urlStr;
             return;
         }
 
@@ -303,7 +305,7 @@ QStringList ConnectToServerDialog::updateCollections(const QString &newUrlStr, b
     QUrl newUrl = QUrl::fromUserInput(newUrlStr);
 
     if (newUrl.host().isEmpty()) {
-        fmWarning() << "invalid url" << newUrlStr << "refuse to collect.";
+        fmWarning() << "Invalid URL provided for collection:" << newUrlStr;
         DialogManagerInstance->showErrorDialog(tr("Error"),
                                                tr("Unable to favorite illegitimate url!"));
         return collections;
@@ -338,7 +340,7 @@ QString ConnectToServerDialog::getCurrentUrlString()
         return url;
 
     if (url.contains(QRegularExpression(R"([?&]charset=)"))) {
-        fmInfo() << "user passed the charset param in url." << url;
+        fmDebug() << "User provided charset parameter in URL:" << url;
         return url;
     }
 
@@ -451,20 +453,16 @@ void ConnectToServerDialog::initializeUi()
         emptyFrame->setMaximumHeight(295);
         emptyFrame->setLayout(emptyLayout);
 
-        DLabel *emptyIcon = new DLabel();
-        emptyIcon->setContentsMargins(120, 40, 0, 0);
-        emptyIcon->setMaximumHeight(200);
-        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
-            emptyIcon->setPixmap(QIcon(":icons/deepin/builtin/light/icons/no_favorites_yet.svg").pixmap({ 145, 145 }));
-        else if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType)
-            emptyIcon->setPixmap(QIcon(":icons/deepin/builtin/dark/icons/no_favorites_yet.svg").pixmap({ 145, 145 }));
+        noFavoritesLabel = new DLabel();
+        noFavoritesLabel->setContentsMargins(120, 40, 0, 0);
+        noFavoritesLabel->setMaximumHeight(200);
 
         DLabel *centerNotes = new DLabel();
         centerNotes->setMaximumHeight(30);
         centerNotes->setText(tr("No favorites yet"));
         centerNotes->setStyleSheet("color:gray;");
 
-        emptyLayout->addWidget(emptyIcon, Qt::AlignHCenter);
+        emptyLayout->addWidget(noFavoritesLabel, Qt::AlignHCenter);
         emptyLayout->addSpacing(5);
         emptyLayout->addWidget(centerNotes, 0, Qt::AlignHCenter | Qt::AlignTop);
         emptyLayout->setSpacing(0);
@@ -508,6 +506,7 @@ void ConnectToServerDialog::initializeUi()
     setContentsMargins(0, 0, 0, 0);
     updateUiState();
     initUiForSizeMode();
+    updateTheme();
 }
 
 void ConnectToServerDialog::initConnect()
@@ -519,6 +518,7 @@ void ConnectToServerDialog::initConnect()
     connect(collectionServerView, &DListView::clicked, this, &ConnectToServerDialog::onCollectionViewClicked);
     connect(schemeComboBox, &DComboBox::currentTextChanged, this, [=](const QString &) { updateUiState(); });
     connect(charsetComboBox, &DComboBox::currentTextChanged, this, [=] { updateUiState(); });
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &ConnectToServerDialog::updateTheme);
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, &ConnectToServerDialog::initUiForSizeMode);
@@ -529,10 +529,14 @@ void ConnectToServerDialog::onAddButtonClicked()
 {
     const QString &currScheme = schemeComboBox->currentText();
     const QString &currHost = serverComboBox->currentText();
-    if (currScheme.isEmpty() || currHost.isEmpty())
+    if (currScheme.isEmpty() || currHost.isEmpty()) {
+        fmWarning() << "Cannot add to favorites: scheme or host is empty";
         return;
+    }
 
     const QString &fullUrlStr = getCurrentUrlString();
+    fmInfo() << "Adding server to favorites:" << fullUrlStr;
+
     const QStringList &collections = updateCollections(fullUrlStr, true);
     model->setStringList(collections);
 
@@ -564,6 +568,7 @@ void ConnectToServerDialog::updateUiState()
     const QString &currUrlStr = getCurrentUrlString();
     int row = model->findItem(currUrlStr);
     collectionServerView->setCurrentIndex(model->index(row));
+    getButton(kConnectButton)->setEnabled(!serverComboBox->currentText().isEmpty());
 }
 
 QString ConnectToServerDialog::schemeWithSlash(const QString &scheme) const
@@ -571,6 +576,15 @@ QString ConnectToServerDialog::schemeWithSlash(const QString &scheme) const
     return scheme + "://";
 }
 
+void ConnectToServerDialog::updateTheme()
+{
+    const auto &noFavoritesIcon = DDciIcon::fromTheme("no_favorites_yet");
+    const auto themeType = DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType
+            ? DDciIcon::Light
+            : DDciIcon::Dark;
+    noFavoritesLabel->setPixmap(noFavoritesIcon.pixmap(qApp->devicePixelRatio(), 145, themeType));
+}
+
 void ConnectToServerDialog::initUiForSizeMode()
 {
 #ifdef DTKWIDGET_CLASS_DSizeMode
