@@ -20,17 +20,12 @@ DWIDGET_USE_NAMESPACE
 using namespace dfmplugin_vault;
 
 VaultActiveStartView::VaultActiveStartView(QWidget *parent)
-    : QWidget(parent)
+    : VaultBaseView(parent)
 {
     initUi();
     initConnect();
 }
 
-void VaultActiveStartView::slotStartBtnClicked()
-{
-    emit sigAccepted();
-}
-
 void VaultActiveStartView::initUi()
 {
     titleLabel = new DLabel(tr("File Vault"), this);
@@ -78,7 +73,7 @@ void VaultActiveStartView::initUiForSizeMode()
 void VaultActiveStartView::initConnect()
 {
     connect(startBtn, &DPushButton::clicked,
-            this, &VaultActiveStartView::slotStartBtnClicked);
+            this, &VaultActiveStartView::accepted);
 #ifdef DTKWIDGET_CLASS_DSizeMode
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [this]() {
         initUiForSizeMode();
