@@ -54,18 +54,37 @@ FileViewModel::FileViewModel(QAbstractItemView *parent)
     connect(DConfigManager::instance(), &DConfigManager::valueChanged, this, &FileViewModel::onDConfigChanged);
     connect(&waitTimer, &QTimer::timeout, this, &FileViewModel::onSetCursorWait);
     waitTimer.setInterval(50);
+
+    fmDebug() << "FileViewModel initialized with key:" << currentKey;
 }
 
 FileViewModel::~FileViewModel()
 {
+    fmDebug() << "FileViewModel destructor started for key:" << currentKey;
     closeCursorTimer();
     quitFilterSortWork();
 
+    // 清理废弃的对象，确保没有资源泄漏
+    for (auto obj : discardedObjects) {
+        if (auto thread = qobject_cast<QThread*>(obj.data())) {
+            if (thread->isRunning()) {
+                thread->quit();
+                if (!thread->wait(1000)) {
+                    fmWarning() << "Force terminating discarded thread in destructor";
+                    thread->terminate();
+                    thread->wait(500);
+                }
+            }
+        }
+    }
+    discardedObjects.clear();
+
     if (itemRootData) {
         delete itemRootData;
         itemRootData = nullptr;
     }
     FileDataManager::instance()->cleanRoot(dirRootUrl, currentKey);
+    fmInfo() << "FileViewModel destructor completed for key:" << currentKey;
 }
 
 QModelIndex FileViewModel::index(int row, int column, const QModelIndex &parent) const
@@ -112,31 +131,66 @@ QModelIndex FileViewModel::rootIndex() const
 
 QModelIndex FileViewModel::setRootUrl(const QUrl &url)
 {
-    if (!url.isValid())
+    if (!url.isValid()) {
+        fmWarning() << "Attempt to set invalid root URL";
         return QModelIndex();
+    }
+
+    fmInfo() << "Setting root URL:" << url.toString() << "with strategy:" << static_cast<int>(dirLoadStrategy);
 
     QVariantMap data;
     data.insert("action", "Open");
     WorkspaceEventCaller::sendEnterDirReportLog(data);
 
-    // insert root index
+    setDirectoryLoadStrategy(WorkspaceHelper::instance()->getLoadStrategy(url.scheme()));
+
+    // 检查是否需要使用保留策略处理
+    bool usePreserveStrategy = !filterSortWorker.isNull() && dirLoadStrategy == DirectoryLoadStrategy::kPreserve;
+
+    if (usePreserveStrategy) {
+        fmDebug() << "Using preserve strategy for URL:" << url.toString();
+        // 仅准备URL，而不立即加载，这样可以保留当前视图内容
+        prepareUrl(url);
+
+        // 如果有预处理器，处理它
+        if (WorkspaceHelper::instance()->haveViewRoutePrehandler(url.scheme())) {
+            auto prehandler = WorkspaceHelper::instance()->viewRoutePrehandler(url.scheme());
+            if (prehandler) {
+                fmDebug() << "Executing prehandler for scheme:" << url.scheme();
+                quint64 winId = FileManagerWindowsManager::instance().findWindowId(qobject_cast<FileView *>(QObject::parent()));
+                prehandler(winId, url, [this]() {
+                    // 预处理完成后执行加载
+                    this->executeLoad();
+                });
+                return rootIndex(); // 返回当前索引，保持UI状态
+            }
+        }
+
+        // 执行加载，但保留当前视图状态
+        executeLoad();
+        return rootIndex();
+    }
+
+    // 标准的创建新模型流程 - kCreateNew策略
+    fmDebug() << "Using create new strategy for URL:" << url.toString();
     beginResetModel();
     closeCursorTimer();
+    discardFilterSortObjects(); // 确保清理旧的资源
+
     // create root by url
     dirRootUrl = url;
-    RootInfo *root = FileDataManager::instance()->fetchRoot(dirRootUrl);
+    FileDataManager::instance()->fetchRoot(dirRootUrl);
     endResetModel();
 
     initFilterSortWork();
 
-    // connect signals
-    connectRootAndFilterSortWork(root);
     // fetch files
     const QModelIndex &index = rootIndex();
 
     if (WorkspaceHelper::instance()->haveViewRoutePrehandler(url.scheme())) {
         auto prehandler = WorkspaceHelper::instance()->viewRoutePrehandler(url.scheme());
         if (prehandler) {
+            fmDebug() << "Executing prehandler for scheme:" << url.scheme();
             quint64 winId = FileManagerWindowsManager::instance().findWindowId(qobject_cast<FileView *>(QObject::parent()));
             prehandler(winId, url, [this, index, url]() {
                 this->canFetchFiles = true;
@@ -150,13 +204,16 @@ QModelIndex FileViewModel::setRootUrl(const QUrl &url)
         fetchMore(index);
     }
 
+    fmInfo() << "Root URL set successfully:" << url.toString();
     return index;
 }
 
 void FileViewModel::doExpand(const QModelIndex &index)
 {
-    if (!index.isValid())
+    if (!index.isValid()) {
+        fmWarning() << "Attempt to expand invalid index";
         return;
+    }
 
     if (!filterSortWorker) {
         fmWarning() << "The model do not stand by, beacuse the sort worker unexist.";
@@ -164,6 +221,8 @@ void FileViewModel::doExpand(const QModelIndex &index)
     }
 
     const QUrl &url = index.data(kItemUrlRole).toUrl();
+    fmInfo() << "Expanding item:" << url.toString();
+
     RootInfo *expandRoot = FileDataManager::instance()->fetchRoot(url);
 
     connect(
@@ -172,6 +231,7 @@ void FileViewModel::doExpand(const QModelIndex &index)
     connect(expandRoot, &RootInfo::sourceDatas, filterSortWorker.data(), &FileSortWorker::handleSourceChildren, Qt::QueuedConnection);
     connect(expandRoot, &RootInfo::iteratorLocalFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorLocalChildren, Qt::QueuedConnection);
     connect(expandRoot, &RootInfo::iteratorAddFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorChildren, Qt::QueuedConnection);
+    connect(expandRoot, &RootInfo::iteratorUpdateFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorChildrenUpdate, Qt::QueuedConnection);
     connect(expandRoot, &RootInfo::watcherAddFiles, filterSortWorker.data(), &FileSortWorker::handleWatcherAddChildren, Qt::QueuedConnection);
     connect(expandRoot, &RootInfo::watcherRemoveFiles, filterSortWorker.data(), &FileSortWorker::handleWatcherRemoveChildren, Qt::QueuedConnection);
     connect(expandRoot, &RootInfo::watcherUpdateFile, filterSortWorker.data(), &FileSortWorker::handleWatcherUpdateFile, Qt::QueuedConnection);
@@ -191,10 +251,14 @@ void FileViewModel::doExpand(const QModelIndex &index)
 
 void FileViewModel::doCollapse(const QModelIndex &index)
 {
-    if (!index.isValid())
+    if (!index.isValid()) {
+        fmWarning() << "Attempt to collapse invalid index";
         return;
+    }
 
     const QUrl &collapseUrl = index.data(kItemUrlRole).toUrl();
+    fmInfo() << "Collapsing item:" << collapseUrl.toString();
+
     Q_EMIT requestCollapseItem(currentKey, collapseUrl);
 
     FileItemDataPointer item = filterSortWorker->childData(index.row());
@@ -362,6 +426,7 @@ QVariant FileViewModel::headerData(int column, Qt::Orientation, int role) const
 
 void FileViewModel::refresh()
 {
+    fmInfo() << "Refreshing view for URL:" << dirRootUrl.toString();
     FileDataManager::instance()->cleanRoot(dirRootUrl, currentKey, true);
 
     Q_EMIT requestRefreshAllChildren();
@@ -379,6 +444,7 @@ void FileViewModel::fetchMore(const QModelIndex &parent)
     // other fetch: fetch file list from data cache
     if (!canFetchMore(parent)) {
         QApplication::restoreOverrideCursor();
+        fmDebug() << "Cannot fetch more data for URL:" << fetchingUrl.toString();
         return;
     }
     canFetchFiles = false;
@@ -390,6 +456,8 @@ void FileViewModel::fetchMore(const QModelIndex &parent)
         return;
     }
 
+    fmDebug() << "Starting to fetch files for URL:" << fetchingUrl.toString();
+
     if (filterSortWorker.isNull()) {
         ret = FileDataManager::instance()->fetchFiles(fetchingUrl, currentKey);
     } else {
@@ -400,8 +468,11 @@ void FileViewModel::fetchMore(const QModelIndex &parent)
     }
 
     if (ret) {
+        fmDebug() << "File fetch request sent successfully for URL:" << fetchingUrl.toString();
         changeState(ModelState::kBusy);
         startCursorTimer();
+    } else {
+        fmWarning() << "Failed to fetch files for URL:" << fetchingUrl.toString();
     }
 }
 
@@ -548,18 +619,37 @@ Qt::DropActions FileViewModel::supportedDropActions() const
 
 void FileViewModel::sort(int column, Qt::SortOrder order)
 {
+    if (state == ModelState::kBusy) {
+        fmWarning() << "Cannot sort while model is busy";
+        return;
+    }
+
     ItemRoles role = getRoleByColumn(column);
+    fmInfo() << "Sorting by column:" << column << "role:" << role << "order:" << (order == Qt::AscendingOrder ? "Ascending" : "Descending");
+
     Q_EMIT requestSortChildren(order, role,
                                Application::instance()->appAttribute(Application::kFileAndDirMixedSort).toBool());
 }
 
-void FileViewModel::stopTraversWork()
+void FileViewModel::stopTraversWork(const QUrl &newUrl)
 {
-    discardFilterSortObjects();
-    FileDataManager::instance()->cleanRoot(dirRootUrl, currentKey);
+    fmInfo() << "Stopping traversal work, current URL:" << dirRootUrl.toString() << "new URL:" << newUrl.toString();
 
     changeState(ModelState::kIdle);
     closeCursorTimer();
+
+    bool canUsePreserveStrategy = dirRootUrl.isValid() && (newUrl.scheme() == dirRootUrl.scheme());
+    if (dirLoadStrategy == DirectoryLoadStrategy::kPreserve && canUsePreserveStrategy) {
+        fmDebug() << "Using preserve strategy to stop work";
+        // stop work but do not clean current data
+        FileDataManager::instance()->stopRootWork(dirRootUrl, currentKey);
+        FileDataManager::instance()->cleanUnusedRoots(dirRootUrl, currentKey);
+        return;
+    }
+
+    fmDebug() << "Cleaning all data due to strategy or scheme change";
+    discardFilterSortObjects();
+    FileDataManager::instance()->cleanRoot(dirRootUrl, currentKey);
 }
 
 QList<ItemRoles> FileViewModel::getColumnRoles() const
@@ -675,6 +765,7 @@ ItemRoles FileViewModel::sortRole() const
 
 void FileViewModel::setFilters(QDir::Filters filters)
 {
+    fmDebug() << "Setting filters:" << filters;
     currentFilters = filters;
     Q_EMIT requestChangeFilters(filters);
 }
@@ -689,6 +780,7 @@ void FileViewModel::setNameFilters(const QStringList &filters)
     if (nameFilters == filters)
         return;
 
+    fmDebug() << "Setting name filters:" << filters;
     nameFilters = filters;
     Q_EMIT requestChangeNameFilters(filters);
 }
@@ -741,6 +833,88 @@ void FileViewModel::setTreeView(const bool isTree)
     Q_EMIT requestTreeView(isTree);
 }
 
+QStringList FileViewModel::getKeyWords()
+{
+    auto rootInfo = FileDataManager::instance()->fetchRoot(dirRootUrl);
+    if (rootInfo)
+        return rootInfo->getKeyWords();
+
+    return {};
+}
+
+void FileViewModel::setDirectoryLoadStrategy(DirectoryLoadStrategy strategy)
+{
+    dirLoadStrategy = strategy;
+}
+
+DirectoryLoadStrategy FileViewModel::directoryLoadStrategy() const
+{
+    return dirLoadStrategy;
+}
+
+// 准备URL但不执行加载
+void FileViewModel::prepareUrl(const QUrl &url)
+{
+    if (!url.isValid())
+        return;
+
+    preparedUrl = url;
+}
+
+// 执行实际的加载
+void FileViewModel::executeLoad()
+{
+    if (filterSortWorker.isNull()) {
+        // 没有工作线程时，直接创建新的
+        if (preparedUrl.isValid()) {
+            setRootUrl(preparedUrl);
+            preparedUrl = QUrl();
+        }
+        return;
+    }
+
+    // 使用准备好的URL，如果没有设置则使用当前URL
+    QUrl urlToLoad = preparedUrl.isValid() ? preparedUrl : dirRootUrl;
+    if (!urlToLoad.isValid())
+        return;
+
+    // 根据不同策略处理
+    switch (dirLoadStrategy) {
+    case DirectoryLoadStrategy::kCreateNew:
+        // 创建新策略：直接设置新URL，会立即清空旧视图
+        setRootUrl(urlToLoad);
+        break;
+
+    case DirectoryLoadStrategy::kPreserve: {
+        // 保留策略：保留当前视图内容直到新数据加载完成
+
+        // 更新当前URL（但不影响视图显示）
+        dirRootUrl = urlToLoad;
+
+        // 获取目标URL的RootInfo，准备数据获取
+        RootInfo *newRoot = FileDataManager::instance()->fetchRoot(dirRootUrl);
+        newRoot->setFirstBatch(true);
+
+        // 连接信号，使当前filterSortWorker监听新RootInfo的数据
+        connectRootAndFilterSortWork(newRoot, true);
+
+        // 更新状态为获取中
+        changeState(ModelState::kBusy);
+
+        // 触发数据加载过程
+        const QModelIndex &index = rootIndex();
+        canFetchFiles = true;
+        fetchingUrl = urlToLoad;
+        fetchMore(index); // 这是关键 - 触发目录数据迭代逻辑
+
+        break;
+    }
+    }
+
+    // 清除准备的URL
+    preparedUrl = QUrl();
+}
+
 void FileViewModel::onFileThumbUpdated(const QUrl &url, const QString &thumb)
 {
     auto updateIndex = getIndexByUrl(url);
@@ -843,6 +1017,9 @@ void FileViewModel::onHiddenSettingChanged(bool value)
 
 void FileViewModel::onWorkFinish(int visiableCount, int totalCount)
 {
+    fmInfo() << "Work finished for URL:" << dirRootUrl.toString()
+             << "visible files:" << visiableCount << "total files:" << totalCount;
+
     QVariantMap data;
     data.insert("action", "Finish");
     data.insert("visiable files", visiableCount);
@@ -851,6 +1028,13 @@ void FileViewModel::onWorkFinish(int visiableCount, int totalCount)
 
     this->changeState(ModelState::kIdle);
     closeCursorTimer();
+
+    // 如果是保留策略，在加载完成后清理旧的RootInfo对象
+    if (dirLoadStrategy == DirectoryLoadStrategy::kPreserve) {
+        fmDebug() << "Cleaning unused roots after preserve strategy completion";
+        // 获取当前URL所有子目录的RootInfo
+        FileDataManager::instance()->cleanUnusedRoots(dirRootUrl, currentKey);
+    }
 }
 
 void FileViewModel::onDataChanged(int first, int last)
@@ -877,6 +1061,7 @@ void FileViewModel::connectRootAndFilterSortWork(RootInfo *root, const bool refr
     connect(root, &RootInfo::sourceDatas, filterSortWorker.data(), &FileSortWorker::handleSourceChildren, Qt::QueuedConnection);
     connect(root, &RootInfo::iteratorLocalFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorLocalChildren, Qt::QueuedConnection);
     connect(root, &RootInfo::iteratorAddFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorChildren, Qt::QueuedConnection);
+    connect(root, &RootInfo::iteratorUpdateFiles, filterSortWorker.data(), &FileSortWorker::handleIteratorChildrenUpdate, Qt::QueuedConnection);
     connect(root, &RootInfo::watcherAddFiles, filterSortWorker.data(), &FileSortWorker::handleWatcherAddChildren, Qt::QueuedConnection);
     connect(root, &RootInfo::watcherRemoveFiles, filterSortWorker.data(), &FileSortWorker::handleWatcherRemoveChildren, Qt::QueuedConnection);
     connect(root, &RootInfo::watcherUpdateFile, filterSortWorker.data(), &FileSortWorker::handleWatcherUpdateFile, Qt::QueuedConnection);
@@ -890,6 +1075,8 @@ void FileViewModel::connectRootAndFilterSortWork(RootInfo *root, const bool refr
 
 void FileViewModel::initFilterSortWork()
 {
+    fmDebug() << "Initializing filter sort work for URL:" << dirRootUrl.toString();
+
     discardFilterSortObjects();
     filterSortThread.reset(new QThread);
 
@@ -902,6 +1089,7 @@ void FileViewModel::initFilterSortWork()
         } else {
             currentFilters &= ~QDir::Hidden;
         }
+        fmDebug() << "Set default filters:" << currentFilters;
     }
 
     // get sort config
@@ -909,6 +1097,8 @@ void FileViewModel::initFilterSortWork()
     Qt::SortOrder order = static_cast<Qt::SortOrder>(valueMap.value("sortOrder", Qt::SortOrder::AscendingOrder).toInt());
     ItemRoles role = static_cast<ItemRoles>(valueMap.value("sortRole", kItemFileDisplayNameRole).toInt());
 
+    fmDebug() << "Sort configuration - order:" << (order == Qt::AscendingOrder ? "Ascending" : "Descending") << "role:" << role;
+
     if (filterSortWorker)
         filterSortWorker->disconnect();
 
@@ -921,9 +1111,95 @@ void FileViewModel::initFilterSortWork()
     endInsertRows();
     filterSortWorker->setSortAgruments(order, role, Application::instance()->appAttribute(Application::kFileAndDirMixedSort).toBool());
     filterSortWorker->setTreeView(DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()
-                                  && WorkspaceHelper::instance()->supportTreeView(rootUrl().scheme()));
+                                  && WorkspaceHelper::instance()->isViewModeSupported(rootUrl().scheme(), ViewMode::kTreeMode));
     filterSortWorker->moveToThread(filterSortThread.data());
 
+    // 连接信号
+    connectFilterSortWorkSignals();
+
+    RootInfo *root = FileDataManager::instance()->fetchRoot(dirRootUrl);
+    connectRootAndFilterSortWork(root);
+
+    filterSortThread->start();
+    fmInfo() << "Filter sort work initialized and started for URL:" << dirRootUrl.toString();
+}
+
+void FileViewModel::quitFilterSortWork()
+{
+    if (!filterSortWorker.isNull()) {
+        filterSortWorker->disconnect();
+        filterSortWorker->cancel();
+    }
+    if (!filterSortThread.isNull()) {
+        filterSortThread->quit();
+
+        // 等待线程优雅退出，增加超时处理
+        if (!filterSortThread->wait(3000)) {
+            fmWarning() << "FilterSortThread did not exit within 3 seconds, forcing termination";
+            filterSortThread->terminate();
+            if (!filterSortThread->wait(1000)) {
+                fmWarning() << "FilterSortThread termination failed, potential resource leak";
+            }
+        }
+    }
+
+    // 确保智能指针被重置
+    filterSortWorker.reset();
+    filterSortThread.reset();
+}
+
+void FileViewModel::discardFilterSortObjects()
+{
+    if (!filterSortThread.isNull() && !filterSortWorker.isNull()) {
+        auto discardedWorker = filterSortWorker;
+        discardedWorker->cancel();
+        discardedObjects.append(discardedWorker);
+        filterSortWorker.reset();
+
+        auto discardedThread = filterSortThread;
+        discardedThread->disconnect();
+        discardedObjects.append(discardedThread);
+        filterSortThread.reset();
+
+        connect(
+                discardedThread.data(), &QThread::finished, this, [this, discardedWorker, discardedThread] {
+                    discardedObjects.removeAll(discardedWorker);
+                    discardedObjects.removeAll(discardedThread);
+                    discardedThread->disconnect();
+                },
+                Qt::QueuedConnection);
+
+        discardedThread->quit();
+    }
+}
+
+void FileViewModel::changeState(ModelState newState)
+{
+    state = newState;
+    Q_EMIT stateChanged();
+}
+
+void FileViewModel::closeCursorTimer()
+{
+    waitTimer.stop();
+
+    while (QApplication::overrideCursor())
+        QApplication::restoreOverrideCursor();
+}
+
+void FileViewModel::startCursorTimer()
+{
+    if (!waitTimer.isActive())
+        waitTimer.start();
+
+    onSetCursorWait();
+}
+
+void FileViewModel::connectFilterSortWorkSignals()
+{
+    if (filterSortWorker.isNull())
+        return;
+
     // connect signals
     connect(filterSortWorker.data(), &FileSortWorker::insertRows, this, &FileViewModel::onInsert, Qt::QueuedConnection);
     connect(filterSortWorker.data(), &FileSortWorker::insertFinish, this, &FileViewModel::onInsertFinish, Qt::QueuedConnection);
@@ -957,7 +1233,6 @@ void FileViewModel::initFilterSortWork()
     connect(this, &FileViewModel::requestSortChildren, filterSortWorker.data(), &FileSortWorker::handleResort, Qt::QueuedConnection);
     connect(this, &FileViewModel::requestSetFilterData, filterSortWorker.data(), &FileSortWorker::handleFilterData, Qt::QueuedConnection);
     connect(this, &FileViewModel::requestSetFilterCallback, filterSortWorker.data(), &FileSortWorker::handleFilterCallFunc, Qt::QueuedConnection);
-    connect(this, &FileViewModel::requestGetSourceData, filterSortWorker.data(), &FileSortWorker::handleModelGetSourceData, Qt::QueuedConnection);
     connect(this, &FileViewModel::requestRefreshAllChildren, filterSortWorker.data(), &FileSortWorker::handleRefresh, Qt::QueuedConnection);
     connect(this, &FileViewModel::requestClearThumbnail, filterSortWorker.data(), &FileSortWorker::handleClearThumbnail, Qt::QueuedConnection);
     connect(this, &FileViewModel::requestShowHiddenChanged, filterSortWorker.data(), &FileSortWorker::onShowHiddenFileChanged, Qt::QueuedConnection);
@@ -966,68 +1241,4 @@ void FileViewModel::initFilterSortWork()
     connect(filterSortWorker.data(), &FileSortWorker::requestUpdateView, this, &FileViewModel::onUpdateView, Qt::QueuedConnection);
     connect(filterSortWorker.data(), &FileSortWorker::aboutToSwitchToListView, this, &FileViewModel::aboutToSwitchToListView, Qt::QueuedConnection);
     connect(Application::instance(), &Application::appAttributeChanged, filterSortWorker.data(), &FileSortWorker::onAppAttributeChanged, Qt::QueuedConnection);
-
-    filterSortThread->start();
-}
-
-void FileViewModel::quitFilterSortWork()
-{
-    if (!filterSortWorker.isNull()) {
-        filterSortWorker->disconnect();
-        filterSortWorker->cancel();
-    }
-    if (!filterSortThread.isNull()) {
-        filterSortThread->quit();
-        filterSortThread->wait();
-    }
-}
-
-void FileViewModel::discardFilterSortObjects()
-{
-    if (!filterSortThread.isNull() && !filterSortWorker.isNull()) {
-        auto discardedWorker = filterSortWorker;
-        discardedWorker->cancel();
-        discardedObjects.append(discardedWorker);
-        filterSortWorker.reset();
-
-        auto discardedThread = filterSortThread;
-        discardedThread->disconnect();
-        discardedObjects.append(discardedThread);
-        filterSortThread.reset();
-
-        connect(
-                discardedThread.data(), &QThread::finished, this, [this, discardedWorker, discardedThread] {
-                    discardedObjects.removeAll(discardedWorker);
-                    discardedObjects.removeAll(discardedThread);
-                    discardedThread->disconnect();
-                },
-                Qt::QueuedConnection);
-
-        discardedThread->quit();
-    }
-}
-
-void FileViewModel::changeState(ModelState newState)
-{
-    if (state == newState)
-        return;
-
-    state = newState;
-    Q_EMIT stateChanged();
-}
-
-void FileViewModel::closeCursorTimer()
-{
-    waitTimer.stop();
-
-    while (QApplication::overrideCursor())
-        QApplication::restoreOverrideCursor();
-}
-
-void FileViewModel::startCursorTimer()
-{
-    if (!waitTimer.isActive())
-        waitTimer.start();
-
-    onSetCursorWait();
 }
