@@ -4,6 +4,7 @@
 
 #include "rootinfo.h"
 #include "fileitemdata.h"
+#include "utils/keywordextractor.h"
 
 #include <dfm-base/base/schemefactory.h>
 #include <dfm-base/utils/universalutils.h>
@@ -21,27 +22,43 @@
 
 using namespace dfmbase;
 using namespace dfmplugin_workspace;
-
 RootInfo::RootInfo(const QUrl &u, const bool canCache, QObject *parent)
     : QObject(parent), url(u), canCache(canCache)
 {
+    fmInfo() << "RootInfo created for URL:" << url.toString() << "canCache:" << canCache;
+
+    // 使用关键字提取器来处理关键字解析
+    keyWords = KeywordExtractorManager::instance().extractor().extractFromUrl(url);
+    
+    if (!keyWords.isEmpty()) {
+        fmDebug() << "Extracted keywords for search:" << keyWords;
+    }
+
     hiddenFileUrl.setScheme(url.scheme());
     hiddenFileUrl.setPath(DFMIO::DFMUtils::buildFilePath(url.path().toStdString().c_str(), ".hidden", nullptr));
 }
 
 RootInfo::~RootInfo()
 {
+    fmInfo() << "RootInfo destructor started for URL:" << url.toString();
+
     disconnect();
-    if (watcher)
+    if (watcher) {
+        fmDebug() << "Stopping file watcher";
         watcher->stopWatcher();
+    }
+
     cancelWatcherEvent = true;
     for (auto &future : watcherEventFutures) {
         future.waitForFinished();
     }
+
+    fmDebug() << "Stopping" << traversalThreads.size() << "traversal threads";
     for (const auto &thread : traversalThreads) {
         thread->traversalThread->stop();
         thread->traversalThread->wait();
     }
+
     // wait old dir iterator thread
     for (const auto &thread : discardedThread) {
         thread->disconnect();
@@ -49,10 +66,16 @@ RootInfo::~RootInfo()
         thread->quit();
         thread->wait();
     }
+
+    fmInfo() << "RootInfo destructor completed for URL:" << url.toString();
 }
 
 bool RootInfo::initThreadOfFileData(const QString &key, DFMGLOBAL_NAMESPACE::ItemRoles role, Qt::SortOrder order, bool isMixFileAndFolder)
 {
+    fmDebug() << "Initializing file data thread for key:" << key << "role:" << role
+              << "order:" << (order == Qt::AscendingOrder ? "Ascending" : "Descending")
+              << "mixFileAndFolder:" << isMixFileAndFolder;
+
     // clear old dir iterator thread
     for (auto it = discardedThread.begin(); it != discardedThread.end();) {
         if (!(*it)->isRunning()) {
@@ -61,10 +84,12 @@ bool RootInfo::initThreadOfFileData(const QString &key, DFMGLOBAL_NAMESPACE::Ite
             it++;
         }
     }
+
     // create traversal thread
     QSharedPointer<DirIteratorThread> traversalThread = traversalThreads.value(key);
     bool isGetCache = canCache;
     if (!traversalThread.isNull()) {
+        fmDebug() << "Disconnecting existing traversal thread for key:" << key;
         traversalThread->traversalThread->disconnect();
     } else {
         isGetCache = (canCache && traversalFinish) || traversaling;
@@ -72,6 +97,8 @@ bool RootInfo::initThreadOfFileData(const QString &key, DFMGLOBAL_NAMESPACE::Ite
             isGetCache = false;
     }
 
+    fmDebug() << "Creating new traversal thread for URL:" << url.toString() << "isGetCache:" << isGetCache;
+
     traversalThread.reset(new DirIteratorThread);
     traversalThread->traversalThread.reset(
             new TraversalDirThreadManager(url, QStringList(),
@@ -105,12 +132,19 @@ bool RootInfo::initThreadOfFileData(const QString &key, DFMGLOBAL_NAMESPACE::Ite
 
 void RootInfo::startWork(const QString &key, const bool getCache)
 {
-    if (!traversalThreads.contains(key))
+    if (!traversalThreads.contains(key)) {
+        fmWarning() << "Cannot start work: traversal thread not found for key:" << key;
         return;
+    }
 
-    if (getCache)
+    fmDebug() << "Starting work for key:" << key << "getCache:" << getCache;
+
+    if (getCache) {
+        fmDebug() << "Using cached data for key:" << key;
         return handleGetSourceData(key);
+    }
 
+    fmInfo() << "Starting directory traversal for URL:" << url.toString();
     traversaling = true;
     {
         QWriteLocker lk(&childrenLock);
@@ -122,10 +156,16 @@ void RootInfo::startWork(const QString &key, const bool getCache)
 
 void RootInfo::startWatcher()
 {
-    if (needStartWatcher == false)
+    if (needStartWatcher == false) {
+        fmDebug() << "File watcher already started or not needed for URL:" << url.toString();
         return;
+    }
+
+    fmInfo() << "Starting file watcher for URL:" << url.toString();
     needStartWatcher = false;
+
     if (watcher) {
+        fmDebug() << "Stopping existing watcher before restart";
         watcher->stopWatcher();
         watcher->disconnect(this);
     }
@@ -137,6 +177,7 @@ void RootInfo::startWatcher()
         return;
     }
 
+    fmDebug() << "Connecting watcher signals for URL:" << url.toString();
     connect(watcher.data(), &AbstractFileWatcher::fileDeleted,
             this, &RootInfo::doFileDeleted);
     connect(watcher.data(), &AbstractFileWatcher::subfileCreated,
@@ -147,32 +188,50 @@ void RootInfo::startWatcher()
             this, &RootInfo::dofileMoved);
 
     watcher->restartWatcher();
+    fmDebug() << "File watcher started successfully for URL:" << url.toString();
 }
 
 int RootInfo::clearTraversalThread(const QString &key, const bool isRefresh)
 {
-    if (!traversalThreads.contains(key))
+    if (!traversalThreads.contains(key)) {
+        fmDebug() << "No traversal thread to clear for key:" << key;
         return traversalThreads.count();
+    }
+
+    fmDebug() << "Clearing traversal thread for key:" << key << "isRefresh:" << isRefresh;
 
     auto thread = traversalThreads.take(key);
     auto traversalThread = thread->traversalThread;
-    if (traversalThread->isRunning())
-        emit traversalFinished(key);
+    if (traversalThread->isRunning()) {
+        fmDebug() << "Emitting traversal finished signal for running thread";
+        emit traversalFinished(key, false);
+    }
     traversalThread->disconnect(this);
     if (traversalThread->isRunning()) {
+        fmDebug() << "Moving running thread to discarded list";
         discardedThread.append(traversalThread);
         traversaling = false;
     }
     thread->traversalThread->stop();
-    if (traversalThreads.isEmpty())
+    if (traversalThreads.isEmpty()) {
+        fmDebug() << "All traversal threads cleared, enabling watcher restart";
         needStartWatcher = true;
+    }
 
     this->isRefresh = isRefresh;
+    fmDebug() << "Traversal threads remaining:" << traversalThreads.count();
     return traversalThreads.count();
 }
 
+void RootInfo::setFirstBatch(bool first)
+{
+    isFirstBatch = first;
+}
+
 void RootInfo::reset()
 {
+    fmInfo() << "Resetting RootInfo for URL:" << url.toString();
+
     disconnect();
 
     {
@@ -199,6 +258,8 @@ void RootInfo::reset()
         thread->stop();
         thread->quit();
     }
+
+    fmDebug() << "RootInfo reset completed";
 }
 
 bool RootInfo::canDelete() const
@@ -219,14 +280,31 @@ bool RootInfo::canDelete() const
     return true;
 }
 
+QStringList RootInfo::getKeyWords() const
+{
+    return keyWords;
+}
+
+bool RootInfo::checkKeyOnly(const QString &key) const
+{
+    for (auto threadKey : traversalThreads.keys()) {
+        if (threadKey != key)
+            return false;
+    }
+
+    return true;
+}
+
 void RootInfo::doFileDeleted(const QUrl &url)
 {
+    fmDebug() << "File deleted event for URL:" << url.toString();
     enqueueEvent(QPair<QUrl, EventType>(url, kRmFile));
     metaObject()->invokeMethod(this, QT_STRINGIFY(doThreadWatcherEvent), Qt::QueuedConnection);
 }
 
 void RootInfo::dofileMoved(const QUrl &fromUrl, const QUrl &toUrl)
 {
+    fmInfo() << "File moved from:" << fromUrl.toString() << "to:" << toUrl.toString();
     Q_EMIT renameFileProcessStarted();
     doFileDeleted(fromUrl);
 
@@ -239,12 +317,14 @@ void RootInfo::dofileMoved(const QUrl &fromUrl, const QUrl &toUrl)
 
 void RootInfo::dofileCreated(const QUrl &url)
 {
+    fmDebug() << "File created event for URL:" << url.toString();
     enqueueEvent(QPair<QUrl, EventType>(url, kAddFile));
     metaObject()->invokeMethod(this, QT_STRINGIFY(doThreadWatcherEvent), Qt::QueuedConnection);
 }
 
 void RootInfo::doFileUpdated(const QUrl &url)
 {
+    fmDebug() << "File updated event for URL:" << url.toString();
     enqueueEvent(QPair<QUrl, EventType>(url, kUpdateFile));
     metaObject()->invokeMethod(this, QT_STRINGIFY(doThreadWatcherEvent), Qt::QueuedConnection);
 }
@@ -372,15 +452,10 @@ void RootInfo::doThreadWatcherEvent()
     });
 }
 
-void RootInfo::handleTraversalResult(const FileInfoPointer &child, const QString &travseToken)
-{
-    auto sortInfo = addChild(child);
-    if (sortInfo)
-        Q_EMIT iteratorAddFile(travseToken, sortInfo, child);
-}
-
 void RootInfo::handleTraversalResults(const QList<FileInfoPointer> children, const QString &travseToken)
 {
+    fmDebug() << "Handling traversal results for token:" << travseToken << "children count:" << children.size();
+
     QList<SortInfoPointer> sortInfos;
     QList<FileInfoPointer> infos;
     for (const auto &info : children) {
@@ -392,8 +467,24 @@ void RootInfo::handleTraversalResults(const QList<FileInfoPointer> children, con
         infos.append(info);
     }
 
-    if (sortInfos.length() > 0)
-        Q_EMIT iteratorAddFiles(travseToken, sortInfos, infos);
+    if (sortInfos.length() > 0) {
+        bool isFirst = isFirstBatch.exchange(false);   // Get and reset the flag
+        fmDebug() << "Emitting iterator add files signal - sortInfos:" << sortInfos.size() << "isFirst:" << isFirst;
+        Q_EMIT iteratorAddFiles(travseToken, sortInfos, infos, isFirst);
+    }
+}
+
+void RootInfo::handleTraversalResultsUpdate(const QList<SortInfoPointer> children, const QString &travseToken)
+{
+    if (children.isEmpty())
+        return;
+
+    QWriteLocker lk(&childrenLock);
+    // 更新已存在的文件信息
+    sourceDataList = children;
+
+    bool isFirst = isFirstBatch.exchange(false);   // Get and reset the flag
+    Q_EMIT iteratorUpdateFiles(travseToken, sourceDataList, isFirst);
 }
 
 void RootInfo::handleTraversalLocalResult(QList<SortInfoPointer> children,
@@ -404,18 +495,31 @@ void RootInfo::handleTraversalLocalResult(QList<SortInfoPointer> children,
     originSortOrder = sortOrder;
     originMixSort = isMixDirAndFile;
 
-    addChildren(children);
-    traversaling = false;
+    if (children.isEmpty())
+        return;
 
-    Q_EMIT iteratorLocalFiles(travseToken, children, originSortRole, originSortOrder, originMixSort);
+    addChildren(children);
+
+    bool isFirst = isFirstBatch.exchange(false);   // Get and reset the flag
+    Q_EMIT iteratorLocalFiles(travseToken, children, originSortRole, originSortOrder, originMixSort, isFirst);
 }
 
 void RootInfo::handleTraversalFinish(const QString &travseToken)
 {
+    fmInfo() << "Traversal finished for token:" << travseToken << "URL:" << url.toString();
+
     traversaling = false;
-    emit traversalFinished(travseToken);
+    // Check if isFirstBatch is still true, which means no directory data was produced
+    bool noDataProduced = isFirstBatch.load();
+    // Reset isFirstBatch
+    isFirstBatch.store(false);
+
+    fmDebug() << "Emitting traversal finished signal - noDataProduced:" << noDataProduced;
+    // Emit signal with additional parameter indicating if no data was produced
+    emit traversalFinished(travseToken, noDataProduced);
     traversalFinish = true;
     if (isRefresh) {
+        fmDebug() << "Refresh completed, resetting refresh flag";
         isRefresh = false;
     }
 }
@@ -431,20 +535,24 @@ void RootInfo::handleGetSourceData(const QString &currentToken)
         startWatcher();
 
     QList<SortInfoPointer> newDatas;
+    bool isEmpty = false;
     {
         QWriteLocker wlk(&childrenLock);
         newDatas = sourceDataList;
+        isEmpty = sourceDataList.isEmpty();
     }
 
     emit sourceDatas(currentToken, newDatas, originSortRole, originSortOrder, originMixSort, !traversaling);
     if (!traversaling)
-        emit traversalFinished(currentToken);
+        emit traversalFinished(currentToken, isEmpty);
 }
 
 void RootInfo::initConnection(const TraversalThreadManagerPointer &traversalThread)
 {
     connect(traversalThread.data(), &TraversalDirThreadManager::updateChildrenManager,
             this, &RootInfo::handleTraversalResults, Qt::DirectConnection);
+    connect(traversalThread.data(), &TraversalDirThreadManager::updateChildrenInfo,
+            this, &RootInfo::handleTraversalResultsUpdate, Qt::DirectConnection);
     connect(traversalThread.data(), &TraversalDirThreadManager::updateLocalChildren,
             this, &RootInfo::handleTraversalLocalResult, Qt::DirectConnection);
     connect(traversalThread.data(), &TraversalDirThreadManager::traversalRequestSort,
@@ -544,6 +652,11 @@ SortInfoPointer RootInfo::sortFileInfo(const FileInfoPointer &info)
     sortInfo->setReadable(info->isAttributes(OptInfoType::kIsReadable));
     sortInfo->setWriteable(info->isAttributes(OptInfoType::kIsWritable));
     sortInfo->setExecutable(info->isAttributes(OptInfoType::kIsExecutable));
+    sortInfo->setLastReadTime(info->timeOf(TimeInfoType::kLastRead).value<QDateTime>().toSecsSinceEpoch());
+    sortInfo->setLastModifiedTime(info->timeOf(TimeInfoType::kLastModified).value<QDateTime>().toSecsSinceEpoch());
+    sortInfo->setCreateTime(info->timeOf(TimeInfoType::kCreateTime).value<QDateTime>().toSecsSinceEpoch());
+    sortInfo->setDisplayType(info->displayOf(DisPlayInfoType::kMimeTypeDisplayName));
+    sortInfo->setInfoCompleted(true);
     return sortInfo;
 }
 
