@@ -7,7 +7,6 @@
 #include "private/fileview_p.h"
 #include "models/fileselectionmodel.h"
 #include "models/fileviewmodel.h"
-#include "models/rootinfo.h"
 #include "baseitemdelegate.h"
 #include "iconitemdelegate.h"
 #include "listitemdelegate.h"
@@ -23,8 +22,6 @@
 #include "utils/shortcuthelper.h"
 #include "utils/fileviewmenuhelper.h"
 #include "utils/fileoperatorhelper.h"
-#include "utils/filedatamanager.h"
-#include "utils/itemdelegatehelper.h"
 #include "utils/viewanimationhelper.h"
 #include "events/workspaceeventsequence.h"
 
@@ -68,7 +65,7 @@ using namespace GlobalDConfDefines::BaseConfig;
 FileView::FileView(const QUrl &url, QWidget *parent)
     : DListView(parent), d(new FileViewPrivate(this))
 {
-    Q_UNUSED(url);
+    d->url = url;
     setMinimumHeight(10);
     setDragDropMode(QAbstractItemView::DragDrop);
     setDropIndicatorShown(false);
@@ -81,6 +78,8 @@ FileView::FileView(const QUrl &url, QWidget *parent)
     setDefaultDropAction(Qt::CopyAction);
     setDragDropOverwriteMode(true);
     setDragEnabled(true);
+//  TODO (search): perf
+//  setLayoutMode(QListView::Batched);
 #ifdef QT_SCROLL_WHEEL_ANI
     QScrollBar *bar = verticalScrollBar();
     bar->setSingleStep(1);
@@ -101,11 +100,15 @@ FileView::FileView(const QUrl &url, QWidget *parent)
 
 FileView::~FileView()
 {
+    fmInfo() << "Destroying FileView for URL:" << rootUrl();
+
     disconnect(model(), &FileViewModel::stateChanged, this, &FileView::onModelStateChanged);
     disconnect(selectionModel(), &QItemSelectionModel::selectionChanged, this, &FileView::onSelectionChanged);
 
     dpfSignalDispatcher->unsubscribe("dfmplugin_workspace", "signal_View_HeaderViewSectionChanged", this, &FileView::onHeaderViewSectionChanged);
     dpfSignalDispatcher->unsubscribe("dfmplugin_filepreview", "signal_ThumbnailDisplay_Changed", this, &FileView::onWidgetUpdate);
+
+    fmDebug() << "FileView destruction completed";
 }
 
 QWidget *FileView::widget() const
@@ -211,17 +214,16 @@ void FileView::setDelegate(Global::ViewMode mode, BaseItemDelegate *view)
 
 bool FileView::setRootUrl(const QUrl &url)
 {
+    d->url = url;
+
     clearSelection();
     selectionModel()->clear();
     d->statusBar->itemCounted(0);
 
-    // Todo(yanghao&lzj):!url.isSearchFile()
-    setFocus();
-
     const QUrl &fileUrl = parseSelectedUrl(url);
     const QModelIndex &index = model()->setRootUrl(fileUrl);
     d->itemsExpandable = DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()
-            && WorkspaceHelper::instance()->supportTreeView(fileUrl.scheme());
+            && WorkspaceHelper::instance()->isViewModeSupported(rootUrl().scheme(), DFMGLOBAL_NAMESPACE::ViewMode::kTreeMode);
 
     setRootIndex(index);
 
@@ -307,9 +309,9 @@ void FileView::setModel(QAbstractItemModel *model)
     DListView::setModel(model);
 }
 
-void FileView::stopWork()
+void FileView::stopWork(const QUrl &newUrl)
 {
-    model()->stopTraversWork();
+    model()->stopTraversWork(newUrl);
 }
 
 void FileView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
@@ -461,6 +463,9 @@ void FileView::onHeaderHiddenChanged(const QString &roleName, const bool isHidde
 
 void FileView::onSortIndicatorChanged(int logicalIndex, Qt::SortOrder order)
 {
+    if (model()->currentState() == ModelState::kBusy)
+        return;
+
     recordSelectedUrls();
 
     model()->sort(logicalIndex, order);
@@ -554,11 +559,15 @@ void FileView::delayUpdateStatusBar()
 void FileView::viewModeChanged(quint64 windowId, int viewMode)
 {
     Global::ViewMode mode = static_cast<Global::ViewMode>(viewMode);
+    if (currentViewMode() == mode) {
+        qWarning() << "Current view mode equal to the new view mode that switched by global event. Don't need to do anything.";
+        return;
+    }
+
     if (mode == Global::ViewMode::kIconMode || mode == Global::ViewMode::kListMode || mode == Global::ViewMode::kTreeMode) {
         setViewMode(mode);
     }
 
-    setFocus();
     saveViewModeState();
 }
 
@@ -739,6 +748,9 @@ void FileView::setEnabledSelectionModes(const QList<QAbstractItemView::Selection
 
 void FileView::setSort(const ItemRoles role, const Qt::SortOrder order)
 {
+    if (model()->currentState() == ModelState::kBusy)
+        return;
+
     if (role == model()->sortRole() && order == model()->sortOrder())
         return;
 
@@ -1116,14 +1128,14 @@ void FileView::onDefaultViewModeChanged(int mode)
 {
     Global::ViewMode newMode = static_cast<Global::ViewMode>(mode);
 
-    if (newMode == Global::ViewMode::kTreeMode && !WorkspaceHelper::instance()->supportTreeView(rootUrl().scheme()))
+    if (!WorkspaceHelper::instance()->isViewModeSupported(rootUrl().scheme(), newMode))
         return;
 
     if (newMode == d->currentViewMode)
         return;
 
     Global::ViewMode oldMode = d->currentViewMode;
-    loadViewState(rootUrl());
+    d->loadViewMode(rootUrl());
 
     if (oldMode == d->currentViewMode)
         return;
@@ -1162,6 +1174,9 @@ void FileView::onItemHeightLevelChanged(int level)
     if (!itemDelegate())
         return;
 
+    if (!d->fileViewHelper->canChangeListItemHeight())
+        return;
+
     if (itemDelegate()->minimumHeightLevel() == level && d->currentListHeightLevel == level)
         return;
 
@@ -1212,12 +1227,16 @@ QList<QAbstractItemView::SelectionMode> FileView::fetchSupportSelectionModes()
 bool FileView::cdUp()
 {
     const QUrl &oldCurrentUrl = rootUrl();
+    fmInfo() << "Navigating up from URL:" << oldCurrentUrl;
+
     QUrl parentUrl = UrlRoute::urlParent(oldCurrentUrl);
 
     if (parentUrl.isValid()) {
+        fmDebug() << "Parent URL found:" << parentUrl;
         FileOperatorHelperIns->openFilesByMode(this, { parentUrl }, DirOpenMode::kOpenInCurrentWindow);
         return true;
     } else {
+        fmDebug() << "No valid parent URL, navigating to computer root";
         auto windowId = WorkspaceHelper::instance()->windowId(this);
         QUrl computerRoot;
         computerRoot.setScheme(Global::Scheme::kComputer);
@@ -1346,17 +1365,27 @@ void FileView::onRowCountChanged()
 
 void FileView::setFilterData(const QUrl &url, const QVariant &data)
 {
+    fmDebug() << "Setting filter data for URL:" << url << "current URL:" << rootUrl();
+
     if (url == rootUrl() && isVisible()) {
+        fmInfo() << "Applying filter data to current view";
         clearSelection();
         model()->setFilterData(data);
+    } else {
+        fmDebug() << "Filter data not applied - URL mismatch or view not visible";
     }
 }
 
 void FileView::setFilterCallback(const QUrl &url, const FileViewFilterCallback callback)
 {
+    fmDebug() << "Setting filter callback for URL:" << url << "current URL:" << rootUrl();
+
     if (url == rootUrl() && isVisible()) {
+        fmInfo() << "Applying filter callback to current view";
         clearSelection();
         model()->setFilterCallback(callback);
+    } else {
+        fmDebug() << "Filter callback not applied - URL mismatch or view not visible";
     }
 }
 
@@ -1745,12 +1774,6 @@ QModelIndexList FileView::selectedIndexes() const
     return QModelIndexList();
 }
 
-void FileView::showEvent(QShowEvent *event)
-{
-    DListView::showEvent(event);
-    setFocus();
-}
-
 void FileView::keyboardSearch(const QString &search)
 {
     d->fileViewHelper->keyboardSearch(search);
@@ -1760,22 +1783,31 @@ void FileView::contextMenuEvent(QContextMenuEvent *event)
 {
     // if the left btn is pressed and the rect large enough, means the view state is draggingSelectState.
     // and don't show menu in the draggingSelectState.
-    if (d->mouseLeftPressed && (abs(d->mouseMoveRect.width()) > kMinMoveLenght || abs(d->mouseMoveRect.height()) > kMinMoveLenght))
+    if (d->mouseLeftPressed && (abs(d->mouseMoveRect.width()) > kMinMoveLenght || abs(d->mouseMoveRect.height()) > kMinMoveLenght)) {
+        fmDebug() << "Context menu blocked due to drag selection state";
         return;
+    }
 
     if (NetworkUtils::instance()->checkFtpOrSmbBusy(rootUrl())) {
+        fmWarning() << "Context menu blocked: FTP or SMB is busy for URL:" << rootUrl();
         DialogManager::instance()->showUnableToVistDir(rootUrl().path());
         return;
     }
 
-    if (FileViewMenuHelper::disableMenu())
+    if (FileViewMenuHelper::disableMenu()) {
+        fmDebug() << "Context menu disabled by helper";
         return;
+    }
 
     d->viewMenuHelper->setWaitCursor();
     const QModelIndex &index = indexAt(event->pos());
-    if (itemDelegate()->editingIndex().isValid() && itemDelegate()->editingIndex() == index)
+    if (itemDelegate()->editingIndex().isValid() && itemDelegate()->editingIndex() == index) {
+        fmDebug() << "Setting focus due to editing index";
         setFocus(Qt::FocusReason::OtherFocusReason);
+    }
+
     if (d->fileViewHelper->isEmptyArea(event->pos())) {
+        fmDebug() << "Showing context menu for empty area";
         BaseItemDelegate *de = itemDelegate();
         if (de)
             de->hideNotEditingIndexWidget();
@@ -1784,10 +1816,12 @@ void FileView::contextMenuEvent(QContextMenuEvent *event)
         d->viewMenuHelper->showEmptyAreaMenu();
     } else {
         if (!isSelected(index)) {
+            fmDebug() << "Item not selected, clearing selection and selecting clicked item";
             itemDelegate()->hideNotEditingIndexWidget();
             clearSelection();
 
             if (!index.isValid()) {
+                fmDebug() << "Invalid index, showing empty area menu";
                 d->viewMenuHelper->showEmptyAreaMenu();
                 d->viewMenuHelper->reloadCursor();
                 return;
@@ -2054,27 +2088,43 @@ void FileView::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int en
     DListView::rowsAboutToBeRemoved(parent, start, end);
 }
 
+void FileView::showEvent(QShowEvent *event)
+{
+    DListView::showEvent(event);
+    focusOnView();
+}
+
 void FileView::initializeModel()
 {
+    fmDebug() << "Initializing FileView model and selection model";
+
     FileViewModel *viewModel = new FileViewModel(this);
     setModel(viewModel);
 
     FileSelectionModel *selectionModel = new FileSelectionModel(viewModel, this);
     setSelectionModel(selectionModel);
+
+    fmDebug() << "Model and selection model initialized successfully";
 }
 
 void FileView::initializeDelegate()
 {
+    fmDebug() << "Initializing FileView delegates";
+
     d->fileViewHelper = new FileViewHelper(this);
     setDelegate(Global::ViewMode::kIconMode, new IconItemDelegate(d->fileViewHelper));
     setDelegate(Global::ViewMode::kListMode, new ListItemDelegate(d->fileViewHelper));
 
     d->itemsExpandable = DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()
-            && WorkspaceHelper::instance()->supportTreeView(rootUrl().scheme());
+            && WorkspaceHelper::instance()->isViewModeSupported(rootUrl().scheme(), DFMGLOBAL_NAMESPACE::ViewMode::kTreeMode);
+
+    fmDebug() << "Delegates initialized, items expandable:" << d->itemsExpandable;
 }
 
 void FileView::initializeStatusBar()
 {
+    fmDebug() << "Initializing FileView status bar";
+
     ViewDefines viewDefines;
     d->statusBar = new FileViewStatusBar(this);
     d->statusBar->resetScalingSlider(viewDefines.iconSizeCount() - 1);
@@ -2084,6 +2134,8 @@ void FileView::initializeStatusBar()
     d->updateStatusBarTimer->setSingleShot(true);
 
     addFooterWidget(d->statusBar);
+
+    fmDebug() << "Status bar initialized with" << viewDefines.iconSizeCount() << "icon size levels";
 }
 
 void FileView::initializeConnect()
@@ -2382,10 +2434,17 @@ void FileView::loadViewState(const QUrl &url)
 
     QVariant defaultIconSize = Application::instance()->appAttribute(Application::kIconSizeLevel).toInt();
     QVariant defaultGridDensity = Application::instance()->appAttribute(Application::kGridDensityLevel).toInt();
-    QVariant defaultListHeight = Application::instance()->appAttribute(Application::kListHeightLevel).toInt();
+
     d->currentIconSizeLevel = d->fileViewStateValue(url, "iconSizeLevel", defaultIconSize).toInt();
     d->currentGridDensityLevel = d->fileViewStateValue(url, "gridDensityLevel", defaultGridDensity).toInt();
-    d->currentListHeightLevel = d->fileViewStateValue(url, "listHeightLevel", defaultListHeight).toInt();
+
+    int customListHeightLevel = d->fileViewHelper->customDefaultListItemHeightLevel();
+    QVariant defaultListHeight = customListHeightLevel >= 0 ? customListHeightLevel : Application::instance()->appAttribute(Application::kListHeightLevel).toInt();
+    if (d->fileViewHelper->canChangeListItemHeight()) {
+        d->currentListHeightLevel = d->fileViewStateValue(url, "listHeightLevel", defaultListHeight).toInt();
+    } else {
+        d->currentListHeightLevel = customListHeightLevel;
+    }
 }
 
 void FileView::onModelStateChanged()
@@ -2395,8 +2454,18 @@ void FileView::onModelStateChanged()
     updateSelectedUrl();
 
     if (model()->currentState() == ModelState::kBusy) {
+        fmDebug() << "Model is busy - disabling header interactions";
+        if (d->headerView) {
+            d->headerView->setSortIndicatorShown(false);
+            d->headerView->setSectionsClickable(false);
+        }
         d->animationHelper->reset();
     } else {
+        fmDebug() << "Model is idle - enabling header interactions";
+        if (d->headerView) {
+            d->headerView->setSortIndicatorShown(true);
+            d->headerView->setSectionsClickable(true);
+        }
         d->animationHelper->initAnimationHelper();
     }
 
@@ -2423,10 +2492,16 @@ void FileView::openIndex(const QModelIndex &index)
 {
     const FileInfoPointer &info = model()->fileInfo(index);
 
-    if (!info)
+    if (!info) {
+        fmWarning() << "Cannot open index: file info is null";
         return;
-    if (NetworkUtils::instance()->checkFtpOrSmbBusy(info->urlOf(UrlInfoType::kUrl))) {
-        DialogManager::instance()->showUnableToVistDir(info->urlOf(UrlInfoType::kUrl).path());
+    }
+
+    QUrl fileUrl = info->urlOf(UrlInfoType::kUrl);
+    fmInfo() << "Opening file:" << fileUrl;
+    if (NetworkUtils::instance()->checkFtpOrSmbBusy(fileUrl)) {
+        fmWarning() << "Cannot open file: FTP or SMB is busy for URL:" << fileUrl;
+        DialogManager::instance()->showUnableToVistDir(fileUrl.path());
         return;
     }
 
@@ -2449,3 +2524,12 @@ void FileView::saveViewModeState()
     setFileViewStateValue(url, "iconSizeLevel", d->statusBar->scalingSlider()->value());
     setFileViewStateValue(url, "viewMode", static_cast<int>(d->currentViewMode));
 }
+
+void FileView::focusOnView()
+{
+    if (WorkspaceHelper::instance()->isFocusFileViewDisabled(d->url.scheme()))
+        return;
+
+    if (isVisible())
+        setFocus();
+}
