@@ -489,13 +489,13 @@ void ListItemDelegate::paintItemColumn(QPainter *painter, const QStyleOptionView
         Qt::TextElideMode elideMode = Qt::ElideRight;
 
         QRectF textRect = columnRect;
-        textRect.setHeight(d->textLineHeight);
-        textRect.moveTop(((columnRect.height() - textRect.height()) / 2) + columnRect.top());
-
         const QUrl &url = parent()->parent()->model()->data(index, kItemUrlRole).toUrl();
         if (rol == kItemNameRole || rol == kItemFileDisplayNameRole) {
             paintFileName(painter, opt, index, rol, textRect, d->textLineHeight, url);
         } else {
+            textRect.setHeight(d->textLineHeight);
+            textRect.moveTop(((columnRect.height() - textRect.height()) / 2) + columnRect.top());
+
             if (!isSelected)
                 painter->setPen(opt.palette.color(cGroup, QPalette::Text));
 
@@ -513,64 +513,141 @@ void ListItemDelegate::paintItemColumn(QPainter *painter, const QStyleOptionView
 void ListItemDelegate::paintFileName(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index, const int &role, const QRectF &rect, const int &textLineHeight,
                                      const QUrl &url) const
 {
-    bool drawBackground = (option.state & QStyle::State_Selected) && option.showDecorationSelected;
     const QVariant &data = index.data(role);
-    painter->setPen(option.palette.color(drawBackground ? QPalette::BrightText : QPalette::Text));
+    if (!data.canConvert<QString>())
+        return;
 
+    bool isSelected = (option.state & QStyle::State_Selected) && option.showDecorationSelected;
+    painter->setPen(option.palette.color(isSelected ? QPalette::BrightText : QPalette::Text));
+
+    const QString previewContent = index.data(kItemFileContentPreviewRole).toString();
+    // 检查是否支持并需要显示内容预览
+    bool showContentPreview = d->paintProxy && d->paintProxy->supportContentPreview() && !previewContent.isEmpty() && index != editingIndex() &&
+            d->itemSizeHint.height() >= d->viewDefines.listHeight(d->viewDefines.listHeightCount() - 1); // 检查是否为最大高度
+
+    QRectF textRect = rect;
+    if (showContentPreview) {
+        // 将矩形区域分为上下两部分
+        QRectF topRect = rect;
+        topRect.setHeight(rect.height() * 0.6);
+
+        textRect = topRect;
+        textRect.setHeight(textLineHeight);
+        textRect.moveTop(((topRect.height() - textRect.height()) / 2) + topRect.top());
+
+        QString fileName = getCorrectDisplayName(painter, index, option, url, role, textLineHeight, textRect);
+        // 绘制文件名(上半部分)
+        QScopedPointer<ElideTextLayout> nameLayout(ItemDelegateHelper::createTextLayout(
+                fileName,
+                QTextOption::WrapAtWordBoundaryOrAnywhere,
+                textLineHeight,
+                index.data(Qt::TextAlignmentRole).toInt(),
+                painter));
+
+        nameLayout->setHighlightEnabled(!isSelected);
+        nameLayout->setHighlightKeywords(parent()->parent()->model()->getKeyWords());
+        nameLayout->setHighlightColor(option.palette.color(QPalette::Active, QPalette::Highlight));
+        nameLayout->layout(textRect, Qt::ElideRight, painter);
+
+        // 绘制文件内容预览(下半部分)
+        painter->save();
+        QFont previewFont = painter->font();
+        previewFont.setPointSize(previewFont.pointSize() - 2);  // Reduce font size by 2
+
+        QRectF contentRect = rect;
+        int contentHeight = QFontMetrics(previewFont).height();
+        static int contentRectOffset = 3;
+        contentRect.moveTop(topRect.bottom() - contentRectOffset);
+        contentRect.setHeight(contentHeight);
+
+        painter->setFont(previewFont);
+        painter->setPen(option.palette.color(isSelected ? QPalette::BrightText : QPalette::PlaceholderText));
+
+        QScopedPointer<ElideTextLayout> contentLayout(ItemDelegateHelper::createTextLayout(
+                previewContent,
+                QTextOption::WrapAtWordBoundaryOrAnywhere,
+                contentHeight,
+                index.data(Qt::TextAlignmentRole).toInt(),
+                painter));
+
+        contentLayout->setHighlightEnabled(!isSelected);
+        contentLayout->setHighlightKeywords(parent()->parent()->model()->getKeyWords());
+        contentLayout->setHighlightColor(option.palette.color(QPalette::Active, QPalette::Highlight));
+        contentLayout->layout(contentRect, Qt::ElideRight, painter);
+        painter->restore();
+    } else {
+        textRect.setHeight(d->textLineHeight);
+        textRect.moveTop(((rect.height() - textRect.height()) / 2) + rect.top());
+        QString fileName = getCorrectDisplayName(painter, index, option, url, role, textLineHeight, textRect);
+        // 原有的单行文件名绘制逻辑
+        QScopedPointer<ElideTextLayout> layout(ItemDelegateHelper::createTextLayout(
+                fileName,
+                QTextOption::WrapAtWordBoundaryOrAnywhere,
+                textLineHeight,
+                index.data(Qt::TextAlignmentRole).toInt(),
+                painter));
+
+        layout->setHighlightEnabled(!isSelected);
+        layout->setHighlightKeywords(parent()->parent()->model()->getKeyWords());
+        layout->setHighlightColor(option.palette.color(QPalette::Active, QPalette::Highlight));
+        layout->layout(textRect, Qt::ElideRight, painter);
+    }
+}
+
+QString ListItemDelegate::getCorrectDisplayName(QPainter *painter, const QModelIndex &index, const QStyleOptionViewItem &option,
+                                                const QUrl &url, const int &role, const int &textLineHeight, const QRectF &rect) const
+{
     QScopedPointer<ElideTextLayout> layout(ItemDelegateHelper::createTextLayout("", QTextOption::WrapAtWordBoundaryOrAnywhere,
                                                                                 textLineHeight, index.data(Qt::TextAlignmentRole).toInt(),
                                                                                 painter));
+    QString displayName { "" };
+    if (Q_LIKELY(!FileUtils::isDesktopFileSuffix(url))) {
+        do {
+            if (role != kItemNameRole && role != kItemFileDisplayNameRole)
+                break;
 
-    if (data.canConvert<QString>()) {
-        QString fileName {};
+            const auto itemFileDisplayName = index.data(kItemFileDisplayNameRole);
+            if (role == kItemFileDisplayNameRole) {
+                const auto itemFileName = index.data(kItemNameRole);
 
-        if (Q_LIKELY(!FileUtils::isDesktopFileSuffix(url))) {
-            do {
-                if (role != kItemNameRole && role != kItemFileDisplayNameRole)
+                if (itemFileName != itemFileDisplayName)
                     break;
+            }
 
-                if (role == kItemFileDisplayNameRole) {
-                    const auto itemFileName = index.data(kItemNameRole);
-                    const auto itemFileDisplayName = index.data(kItemFileDisplayNameRole);
+            const QString &suffix = "." + index.data(kItemFileSuffixRole).toString();
+            if (suffix == ".")
+                break;
 
-                    if (itemFileName != itemFileDisplayName)
-                        break;
-                }
-
-                const QString &suffix = "." + index.data(kItemFileSuffixRole).toString();
-                if (suffix == ".")
-                    break;
-
-                QStringList textList {};
-                layout->setText(index.data(kItemFileBaseNameRole).toString().remove('\n'));
-                QRectF baseNameRect = rect;
-                baseNameRect.adjust(0, 0, -option.fontMetrics.horizontalAdvance(suffix), 0);
-                layout->layout(baseNameRect, Qt::ElideRight, nullptr, Qt::NoBrush, &textList);
-
-                fileName = textList.join('\n');
-
-                bool showSuffix { Application::instance()->genericAttribute(Application::kShowedFileSuffix).toBool() };
-                if (showSuffix)
-                    fileName.append(suffix);
-            } while (false);
-        }
-
-        if (fileName.isEmpty()) {
             QStringList textList {};
-            layout->setText(index.data(role).toString().remove('\n'));
-            layout->layout(rect, Qt::ElideRight, nullptr, Qt::NoBrush, &textList);
+            layout->setText(index.data(kItemFileBaseNameRole).toString().remove('\n'));
+            QRectF baseNameRect = rect;
+            baseNameRect.adjust(0, 0, -option.fontMetrics.horizontalAdvance(suffix), 0);
+            layout->layout(baseNameRect, Qt::ElideRight, nullptr, Qt::NoBrush, &textList);
 
-            fileName = fileName = textList.join('\n');
-        }
-        QScopedPointer<ElideTextLayout> layout(ItemDelegateHelper::createTextLayout(fileName,
-                                                                                    QTextOption::WrapAtWordBoundaryOrAnywhere,
-                                                                                    textLineHeight, index.data(Qt::TextAlignmentRole).toInt(),
-                                                                                    painter));
-        layout->layout(rect, Qt::ElideRight, painter);
-    } else {
-        // Todo(yanghao&liuyangming)???
-        //         drawNotStringData(option, textLineHeight, rect, data, drawBackground, painter, 0);
+            displayName = textList.join('\n');
+
+            auto tmpFileName = displayName;
+            // get error suffix, so show the file displayname
+            if (tmpFileName.append(suffix) != itemFileDisplayName.toString()) {
+                displayName = itemFileDisplayName.toString();
+                break;
+            }
+
+            bool showSuffix { Application::instance()->genericAttribute(Application::kShowedFileSuffix).toBool() };
+            if (showSuffix)
+                displayName.append(suffix);
+        } while (false);
     }
+
+    if (displayName.isEmpty()) {
+        QStringList textList {};
+        layout->setText(index.data(role).toString().remove('\n'));
+        layout->layout(rect, Qt::ElideRight, nullptr, Qt::NoBrush, &textList);
+
+        displayName = textList.join('\n');
+    }
+
+    return displayName;
 }
 
 bool ListItemDelegate::setEditorData(ListItemEditor *editor)
