@@ -24,21 +24,31 @@ CryptSetupCompabilityHelper *CryptSetupCompabilityHelper::instance()
 CryptSetupCompabilityHelper::CryptSetupCompabilityHelper(QObject *parent)
     : QObject { parent }
 {
+    qInfo() << "[CryptSetupCompabilityHelper] Initializing cryptsetup compatibility helper";
+    
     m_libCryptsetup = new QLibrary("libcryptsetup.so.12", this);
     if (!m_libCryptsetup->load()) {
-        qWarning() << "cannot load cryptsetup!";
+        qCritical() << "[CryptSetupCompabilityHelper] Failed to load cryptsetup library";
         return;
     }
+    
+    qInfo() << "[CryptSetupCompabilityHelper] Cryptsetup library loaded successfully";
+    
     auto name = "crypt_reencrypt_init_by_passphrase_with_data_device_preprocess";
     m_func = (InitWithPreProcess)m_libCryptsetup->resolve(name);
-    if (!m_func)
-        qWarning() << "current version do not provide expected function!";
-    else
-        qInfo() << "cryptsetup new API was found.";
+    if (!m_func) {
+        qWarning() << "[CryptSetupCompabilityHelper] Current cryptsetup version does not provide expected function:" << name;
+    } else {
+        qInfo() << "[CryptSetupCompabilityHelper] Cryptsetup new API function found and resolved successfully";
+    }
 }
 
 CryptSetupCompabilityHelper::~CryptSetupCompabilityHelper()
 {
-    if (m_libCryptsetup && m_libCryptsetup->isLoaded())
+    qInfo() << "[CryptSetupCompabilityHelper] Destroying cryptsetup compatibility helper";
+    
+    if (m_libCryptsetup && m_libCryptsetup->isLoaded()) {
         m_libCryptsetup->unload();
+        qInfo() << "[CryptSetupCompabilityHelper] Cryptsetup library unloaded successfully";
+    }
 }
