@@ -17,7 +17,7 @@
 
 #include <DConfig>
 
-#include <polkit-qt5-1/PolkitQt1/Authority>
+#include <polkit-qt6-1/PolkitQt1/Authority>
 #include <sys/mount.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -200,7 +200,7 @@ CifsMountHelper::MountStatus CifsMountHelper::checkMount(const QString &path, QS
     if (fs) {
         mpt = mnt_fs_get_target(fs);
         fmDebug() << "find mounted at: " << mpt << path;
-        if (!mpt.contains(QRegularExpression("^/media/.*/smbmounts/")))
+        if (!mpt.contains(QRegularExpression("^(?:/run/media|/media)/.*")))
             return kNotMountByDaemon;
 
         QString fsType = mnt_fs_get_fstype(fs);
